# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlTypeBeweegbaarBrugdeel(KeuzelijstField):
    """Het type van het beweegbaar brugdeel."""
    naam = 'KlTypeBeweegbaarBrugdeel'
    label = 'Type beweegbaar brugdeel'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#KlTypeBeweegbaarBrugdeel'
    definition = 'Het type van het beweegbaar brugdeel.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlTypeBeweegbaarBrugdeel'
    options = {
        'basculebrug': KeuzelijstWaarde(invulwaarde='basculebrug',
                                        label='Basculebrug',
                                        status='ingebruik',
                                        definitie='Brugdeel dat zich kan openen en sluiten door te draaien om het scharnierpunt, waar het brugdeel (ongeveer) in evenwicht is tussen het gewicht van het brugdek en dat van het contragewicht.',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeBeweegbaarBrugdeel/basculebrug'),
        'draaibrug': KeuzelijstWaarde(invulwaarde='draaibrug',
                                      label='Draaibrug',
                                      status='ingebruik',
                                      definitie='Een brugdeel waarvan het beweegbare deel in een horizontaal vlak om een verticale as kan draaien. Een draaibrug kan gelijke of ongelijke armen hebben: de as waarrond het brugdeel draait, bevindt zich dan respectievelijk in het midden van of aan Ã©Ã©n zijde.',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeBeweegbaarBrugdeel/draaibrug'),
        'geen-standaardtype': KeuzelijstWaarde(invulwaarde='geen-standaardtype',
                                               label='Geen standaardtype',
                                               status='ingebruik',
                                               definitie='Een brugdeel dat kan bewogen worden, maar niet kan beschreven worden door de andere termen. Vb.: een combinatie van bewegingsmethoden.',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeBeweegbaarBrugdeel/geen-standaardtype'),
        'hefbrug': KeuzelijstWaarde(invulwaarde='hefbrug',
                                    label='Hefbrug',
                                    status='ingebruik',
                                    definitie='Een brugdeel waarvan het wegdek recht omhoog opgehesen wordt om de scheepvaart door te laten.',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeBeweegbaarBrugdeel/hefbrug'),
        'helft-dubbele-basculebrug': KeuzelijstWaarde(invulwaarde='helft-dubbele-basculebrug',
                                                      label='Helft dubbele basculebrug',
                                                      status='ingebruik',
                                                      definitie='Bij een dubbele basculebrug hebben de brughelften slechts Ã©Ã©n vast steunpunt, het scharnierpunt. Wanneer het brugdeel gesloten wordt, worden de brughelften aan elkaar verbonden.',
                                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeBeweegbaarBrugdeel/helft-dubbele-basculebrug'),
        'klapbrug': KeuzelijstWaarde(invulwaarde='klapbrug',
                                     label='Klapbrug',
                                     status='ingebruik',
                                     definitie='Soort van basculebrug zonder contragewicht. Het voordeel van dergelijk brugdeel is dat deze minder plaats inneemt, maar het grote nadeel is dat er veel meer energie nodig is om de klapbrug te openen dan bij de volwaardige basculebrug. Daarom worden klapbruggen alleen bij kleine overspanningen gebruikt.',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeBeweegbaarBrugdeel/klapbrug'),
        'ophaalbrug': KeuzelijstWaarde(invulwaarde='ophaalbrug',
                                       label='Ophaalbrug',
                                       status='ingebruik',
                                       definitie='Brugdeel waarvan het brugdek (ook wel de val of de klap genoemd) aan Ã©Ã©n kant scharnierend is opgehangen en aan de andere zijde door middel van een ketting of kabel opgehaald en naar beneden gelaten kan worden.',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeBeweegbaarBrugdeel/ophaalbrug'),
        'pontonbrug': KeuzelijstWaarde(invulwaarde='pontonbrug',
                                       label='Pontonbrug',
                                       status='ingebruik',
                                       definitie='Een brugdeel naar een op het water drijvende ponton. Het brugdeel heeft een scharnier aan de ene kant en rolt aan de andere om toegang tot het ponton vanop de oever toe te laten.',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeBeweegbaarBrugdeel/pontonbrug'),
        'rolbasculebrug': KeuzelijstWaarde(invulwaarde='rolbasculebrug',
                                           label='Rolbasculebrug',
                                           status='ingebruik',
                                           definitie='Een brugdeel dat openklapt en rolt met een behulp van een contragewicht.',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeBeweegbaarBrugdeel/rolbasculebrug'),
        'rolbrug': KeuzelijstWaarde(invulwaarde='rolbrug',
                                    label='Rolbrug',
                                    status='ingebruik',
                                    definitie='Een brugdeel dat op het land gerold wordt om het scheepvaartverkeer door te laten.',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeBeweegbaarBrugdeel/rolbrug'),
        'straussbrug': KeuzelijstWaarde(invulwaarde='straussbrug',
                                        label='Straussbrug',
                                        status='ingebruik',
                                        definitie='Type basculebrug waarvan het tegengewicht zich boven het wegdek bevindt en die door drijfstangen geopend of gesloten wordt.',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeBeweegbaarBrugdeel/straussbrug'),
        'vast': KeuzelijstWaarde(invulwaarde='vast',
                                 label='Vast',
                                 status='ingebruik',
                                 definitie='Een brugdeel dat niet kan bewegen.',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlTypeBeweegbaarBrugdeel/vast')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlGrondHoofdnaamCode(KeuzelijstField):
    """De hoofdnaamcode van de grond.Namespace :http://interpretatie.kern.schemas.dov.vlaanderen.be/GecodeerdHoofdnaamCodesEnumType."""
    naam = 'KlGrondHoofdnaamCode'
    label = 'Grond hoofdnaamcode'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlGrondHoofdnaamCode'
    definition = 'De hoofdnaamcode van de grond.Namespace :http://interpretatie.kern.schemas.dov.vlaanderen.be/GecodeerdHoofdnaamCodesEnumType.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlGrondHoofdnaamCode'
    options = {
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from abc import abstractmethod
from otlmow_model.BaseClasses.StringField import StringField
from otlmow_model.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class ElektrischComponentennummerObject(PuntGeometrie):
    """Abstracte voor Objecttypes waarvoor het componentnummer op het lokale elektrische schema moet bijgehouden worden."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ElektrischComponentennummerObject'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    @abstractmethod
    def __init__(self):
        super().__init__()

        self._componentnummer = OTLAttribuut(field=StringField,
                                             naam='componentnummer',
                                             label='componentnummer',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ElektrischComponentennummerObject.componentnummer',
                                             definition='Het componentnummer van het elektrische toestel, zoals weergegeven op het schema van het lokale laagspanningsbord. Wordt ook wel onderdeelcode (ODC) genoemd.',
                                             owner=self)

    @property
    def componentnummer(self) -> str:
        """Het componentnummer van het elektrische toestel, zoals weergegeven op het schema van het lokale laagspanningsbord. Wordt ook wel onderdeelcode (ODC) genoemd."""
        return self._componentnummer.get_waarde()

    @componentnummer.setter
    def componentnummer(self, value):
        self._componentnummer.set_waarde(value, owner=self)



# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlAntenneFrequentierange(KeuzelijstField):
    """Keuzelijst met frequentiebanden aan waarbinnen een antenne gebruikt kan worden."""
    naam = 'KlAntenneFrequentierange'
    label = 'Antenne frequentierange'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlAntenneFrequentierange'
    definition = 'Keuzelijst met frequentiebanden aan waarbinnen een antenne gebruikt kan worden.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlAntenneFrequentierange'
    options = {
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from typing import List
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.BaseClasses.WaardenObject import WaardenObject
from otlmow_model.BaseClasses.BooleanField import BooleanField
from otlmow_model.BaseClasses.ComplexField import ComplexField
from otlmow_model.Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from otlmow_model.Datatypes.KlBetonmilieuklasse import KlBetonmilieuklasse
from otlmow_model.Datatypes.KlBetonomgevingsklasse import KlBetonomgevingsklasse
from otlmow_model.Datatypes.KlBetonsterkteklasse import KlBetonsterkteklasse
from otlmow_model.Datatypes.KlGebruiksdomein import KlGebruiksdomein
from otlmow_model.Datatypes.KlToeslagmiddelBeton import KlToeslagmiddelBeton
from otlmow_model.Datatypes.KwantWrdInMillimeter import KwantWrdInMillimeter, KwantWrdInMillimeterWaarden


# Generated with OTLComplexDatatypeCreator. To modify: extend, do not edit
class DtcBetonspecificatiesWaarden(WaardenObject):
    def __init__(self):
        WaardenObject.__init__(self)
        self._betondekking = OTLAttribuut(field=KwantWrdInMillimeter,
                                          naam='betondekking',
                                          label='betondekking',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#DtcBetonspecificaties.betondekking',
                                          definition='De afstand in millimeter tussen de buitenkant van het beton (het oppervlak van het beton) tot het dichtstbijzijnde wapeningsstaal.',
                                          owner=self)

        self._betonmilieuklassen = OTLAttribuut(field=KlBetonmilieuklasse,
                                                naam='betonmilieuklassen',
                                                label='betonmilieuklassen',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#DtcBetonspecificaties.betonmilieuklassen',
                                                kardinaliteit_max='*',
                                                definition='Milieuklassen (X-klassen) leggen rechtstreeks de link met bepaalde aantastingsmechanismen, waaraan de betonconstructie (of een onderdeel ervan) wordt blootgesteld tijdens het gebruik. Er kunnen meerdere milieuklassen van toepassing zijn.',
                                                owner=self)

        self._betonomgevingsklassen = OTLAttribuut(field=KlBetonomgevingsklasse,
                                                   naam='betonomgevingsklassen',
                                                   label='betonomgevingsklassen',
                                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#DtcBetonspecificaties.betonomgevingsklassen',
                                                   kardinaliteit_max='*',
                                                   definition='De omgeving waaraan de betonconstructie (of een onderdeel ervan) wordt blootgesteld tijdens het gebruik. Er kunnen meerdere omgevingsklassen van toepassing zijn.',
                                                   owner=self)

        self._betonsterkteklasse = OTLAttribuut(field=KlBetonsterkteklasse,
                                                naam='betonsterkteklasse',
                                                label='betonsterkteklasse',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#DtcBetonspecificaties.betonsterkteklasse',
                                                definition='De sterkteklasse is een maat voor de druksterkte van beton.',
                                                owner=self)

        self._gebruiksdomein = OTLAttribuut(field=KlGebruiksdomein,
                                            naam='gebruiksdomein',
                                            label='gebruiksdomein',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#DtcBetonspecificaties.gebruiksdomein',
                                            definition='De gebruiksomstandigheden van het beton. Dit bepaalt tevens het maximum chloridegehalte.',
                                            owner=self)

        self._grootsteKorrelafmetingDmax = OTLAttribuut(field=KwantWrdInMillimeter,
                                                        naam='grootsteKorrelafmetingDmax',
                                                        label='grootste korrelafmeting (Dmax)',
                                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#DtcBetonspecificaties.grootsteKorrelafmetingDmax',
                                                        definition='De nominale grootste korrelafmeting (Dmax).',
                                                        owner=self)

        self._isCementMetBeperktAlkaligehalte = OTLAttribuut(field=BooleanField,
                                                             naam='isCementMetBeperktAlkaligehalte',
                                                             label='is cement met beperkt alkaligehalte',
                                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#DtcBetonspecificaties.isCementMetBeperktAlkaligehalte',
                                                             definition='Aanduiding of het cement een beperkt alkaligehalte heeft (LA).',
                                                             owner=self)

        self._isCementMetHogeAanvangssterkte = OTLAttribuut(field=BooleanField,
                                                            naam='isCementMetHogeAanvangssterkte',
                                                            label='is cement met hoge aanvangssterkte',
                                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#DtcBetonspecificaties.isCementMetHogeAanvangssterkte',
                                                            definition='Geeft aan of het cement gebruikt wordt voor een snelle binding (bijvoorbeeld in de winter) (HES).',
                                                            owner=self)

        self._isCementMetHogeBestandheidTegenSulfaten = OTLAttribuut(field=BooleanField,
                                                                     naam='isCementMetHogeBestandheidTegenSulfaten',
                                                                     label='is cement met hoge bestandheid tegen sulfaten',
                                                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#DtcBetonspecificaties.isCementMetHogeBestandheidTegenSulfaten',
                                                                     definition='Geeft aan of het cement een hoge bestandheid heeft tegen sulfaten (SR).',
                                                                     owner=self)

        self._isCementMetLageHydratatiewarmte = OTLAttribuut(field=BooleanField,
                                                             naam='isCementMetLageHydratatiewarmte',
                                                             label='is cement met lage hydratatiewarmte',
                                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#DtcBetonspecificaties.isCementMetLageHydratatiewarmte',
                                                             definition='Geeft aan of het cement gebruikt wordt voor een tragere sterkteontwikkeling (LH).',
                                                             owner=self)

        self._isColloidaalbeton = OTLAttribuut(field=BooleanField,
                                               naam='isColloidaalbeton',
                                               label='is colloïdaalbeton',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#DtcBetonspecificaties.isColloidaalbeton',
                                               definition='Geeft aan of het beton zich niet ontmengt onder of in water.',
                                               owner=self)

        self._technischeFiche = OTLAttribuut(field=DtcDocument,
                                             naam='technischeFiche',
                                             label='technische fiche',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#DtcBetonspecificaties.technischeFiche',
                                             usagenote='Attribuut uit gebruik sinds versie 2.5.0 ',
                                             deprecated_version='2.5.0',
                                             definition='De technische fiche van het beton. Deze moet volgende eigenschappen bevatten: de norm waaraan het beton voldoet, de sterkteklasse, de duurzaamheid (bestaande uit het gebruiksdomein en de omgevingsklasse(n)), de consistentieklasse, de nominale grootste korrelafmeting,...',
                                             owner=self)

        self._technischeFicheSpecificatiesBeton = OTLAttribuut(field=DtcDocument,
                                                               naam='technischeFicheSpecificatiesBeton',
                                                               label='technische fiche specificaties beton',
                                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#DtcBetonspecificaties.technischeFicheSpecificatiesBeton',
                                                               definition='De technische fiche van de specificaties van het beton. Deze moet volgende eigenschappen bevatten: de norm waaraan het beton voldoet, de sterkteklasse, de duurzaamheid (bestaande uit het gebruiksdomein en de omgevingsklasse(n)), de consistentieklasse, de nominale grootste korrelafmeting,...',
                                                               owner=self)

        self._toeslagmiddelen = OTLAttribuut(field=KlToeslagmiddelBeton,
                                             naam='toeslagmiddelen',
                                             label='toeslagmiddelen',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#DtcBetonspecificaties.toeslagmiddelen',
                                             kardinaliteit_max='*',
                                             definition='Materialen die aan het beton worden toegevoegd om vb.: een beter geheel te maken, holle ruimten te vullen waardoor de sterkte toeneemt, ruimten met minder massa te creëren,... Dit kunnen er meerdere zijn.',
                                             owner=self)

    @property
    def betondekking(self) -> KwantWrdInMillimeterWaarden:
        """De afstand in millimeter tussen de buitenkant van het beton (het oppervlak van het beton) tot het dichtstbijzijnde wapeningsstaal."""
        return self._betondekking.get_waarde()

    @betondekking.setter
    def betondekking(self, value):
        self._betondekking.set_waarde(value, owner=self._parent)

    @property
    def betonmilieuklassen(self) -> List[str]:
        """Milieuklassen (X-klassen) leggen rechtstreeks de link met bepaalde aantastingsmechanismen, waaraan de betonconstructie (of een onderdeel ervan) wordt blootgesteld tijdens het gebruik. Er kunnen meerdere milieuklassen van toepassing zijn."""
        return self._betonmilieuklassen.get_waarde()

    @betonmilieuklassen.setter
    def betonmilieuklassen(self, value):
        self._betonmilieuklassen.set_waarde(value, owner=self._parent)

    @property
    def betonomgevingsklassen(self) -> List[str]:
        """De omgeving waaraan de betonconstructie (of een onderdeel ervan) wordt blootgesteld tijdens het gebruik. Er kunnen meerdere omgevingsklassen van toepassing zijn."""
        return self._betonomgevingsklassen.get_waarde()

    @betonomgevingsklassen.setter
    def betonomgevingsklassen(self, value):
        self._betonomgevingsklassen.set_waarde(value, owner=self._parent)

    @property
    def betonsterkteklasse(self) -> str:
        """De sterkteklasse is een maat voor de druksterkte van beton."""
        return self._betonsterkteklasse.get_waarde()

    @betonsterkteklasse.setter
    def betonsterkteklasse(self, value):
        self._betonsterkteklasse.set_waarde(value, owner=self._parent)

    @property
    def gebruiksdomein(self) -> str:
        """De gebruiksomstandigheden van het beton. Dit bepaalt tevens het maximum chloridegehalte."""
        return self._gebruiksdomein.get_waarde()

    @gebruiksdomein.setter
    def gebruiksdomein(self, value):
        self._gebruiksdomein.set_waarde(value, owner=self._parent)

    @property
    def grootsteKorrelafmetingDmax(self) -> KwantWrdInMillimeterWaarden:
        """De nominale grootste korrelafmeting (Dmax)."""
        return self._grootsteKorrelafmetingDmax.get_waarde()

    @grootsteKorrelafmetingDmax.setter
    def grootsteKorrelafmetingDmax(self, value):
        self._grootsteKorrelafmetingDmax.set_waarde(value, owner=self._parent)

    @property
    def isCementMetBeperktAlkaligehalte(self) -> bool:
        """Aanduiding of het cement een beperkt alkaligehalte heeft (LA)."""
        return self._isCementMetBeperktAlkaligehalte.get_waarde()

    @isCementMetBeperktAlkaligehalte.setter
    def isCementMetBeperktAlkaligehalte(self, value):
        self._isCementMetBeperktAlkaligehalte.set_waarde(value, owner=self._parent)

    @property
    def isCementMetHogeAanvangssterkte(self) -> bool:
        """Geeft aan of het cement gebruikt wordt voor een snelle binding (bijvoorbeeld in de winter) (HES)."""
        return self._isCementMetHogeAanvangssterkte.get_waarde()

    @isCementMetHogeAanvangssterkte.setter
    def isCementMetHogeAanvangssterkte(self, value):
        self._isCementMetHogeAanvangssterkte.set_waarde(value, owner=self._parent)

    @property
    def isCementMetHogeBestandheidTegenSulfaten(self) -> bool:
        """Geeft aan of het cement een hoge bestandheid heeft tegen sulfaten (SR)."""
        return self._isCementMetHogeBestandheidTegenSulfaten.get_waarde()

    @isCementMetHogeBestandheidTegenSulfaten.setter
    def isCementMetHogeBestandheidTegenSulfaten(self, value):
        self._isCementMetHogeBestandheidTegenSulfaten.set_waarde(value, owner=self._parent)

    @property
    def isCementMetLageHydratatiewarmte(self) -> bool:
        """Geeft aan of het cement gebruikt wordt voor een tragere sterkteontwikkeling (LH)."""
        return self._isCementMetLageHydratatiewarmte.get_waarde()

    @isCementMetLageHydratatiewarmte.setter
    def isCementMetLageHydratatiewarmte(self, value):
        self._isCementMetLageHydratatiewarmte.set_waarde(value, owner=self._parent)

    @property
    def isColloidaalbeton(self) -> bool:
        """Geeft aan of het beton zich niet ontmengt onder of in water."""
        return self._isColloidaalbeton.get_waarde()

    @isColloidaalbeton.setter
    def isColloidaalbeton(self, value):
        self._isColloidaalbeton.set_waarde(value, owner=self._parent)

    @property
    def technischeFiche(self) -> DtcDocumentWaarden:
        """De technische fiche van het beton. Deze moet volgende eigenschappen bevatten: de norm waaraan het beton voldoet, de sterkteklasse, de duurzaamheid (bestaande uit het gebruiksdomein en de omgevingsklasse(n)), de consistentieklasse, de nominale grootste korrelafmeting,..."""
        return self._technischeFiche.get_waarde()

    @technischeFiche.setter
    def technischeFiche(self, value):
        self._technischeFiche.set_waarde(value, owner=self._parent)

    @property
    def technischeFicheSpecificatiesBeton(self) -> DtcDocumentWaarden:
        """De technische fiche van de specificaties van het beton. Deze moet volgende eigenschappen bevatten: de norm waaraan het beton voldoet, de sterkteklasse, de duurzaamheid (bestaande uit het gebruiksdomein en de omgevingsklasse(n)), de consistentieklasse, de nominale grootste korrelafmeting,..."""
        return self._technischeFicheSpecificatiesBeton.get_waarde()

    @technischeFicheSpecificatiesBeton.setter
    def technischeFicheSpecificatiesBeton(self, value):
        self._technischeFicheSpecificatiesBeton.set_waarde(value, owner=self._parent)

    @property
    def toeslagmiddelen(self) -> List[str]:
        """Materialen die aan het beton worden toegevoegd om vb.: een beter geheel te maken, holle ruimten te vullen waardoor de sterkte toeneemt, ruimten met minder massa te creëren,... Dit kunnen er meerdere zijn."""
        return self._toeslagmiddelen.get_waarde()

    @toeslagmiddelen.setter
    def toeslagmiddelen(self, value):
        self._toeslagmiddelen.set_waarde(value, owner=self._parent)


# Generated with OTLComplexDatatypeCreator. To modify: extend, do not edit
class DtcBetonspecificaties(ComplexField):
    """Complex datatype om de eigenschappen van beton te bundelen. Deze omvat onder andere de verschillende betonklassen,hoe het beton gebruikt wordt,eigenschappen van het cement,een technische fiche van het beton,..."""
    naam = 'DtcBetonspecificaties'
    label = 'Betonspecificaties'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#DtcBetonspecificaties'
    definition = 'Complex datatype om de eigenschappen van beton te bundelen. Deze omvat onder andere de verschillende betonklassen,hoe het beton gebruikt wordt,eigenschappen van het cement,een technische fiche van het beton,...'
    waardeObject = DtcBetonspecificatiesWaarden

    def __str__(self):
        return ComplexField.__str__(self)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlLichtmastMasttype(KeuzelijstField):
    """Lijst van mogelijke types voor lichtmasten."""
    naam = 'KlLichtmastMasttype'
    label = 'lichtmast type'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlLichtmastMasttype'
    definition = 'Lijst van mogelijke types voor lichtmasten.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlLichtmastMasttype'
    options = {
        'B': KeuzelijstWaarde(invulwaarde='B',
                              label='B',
                              status='ingebruik',
                              definitie='Betonnen paal',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLichtmastMasttype/B'),
        'BS': KeuzelijstWaarde(invulwaarde='BS',
                               label='BS',
                               status='ingebruik',
                               definitie='Betonnen paal op voet',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLichtmastMasttype/BS'),
        'K': KeuzelijstWaarde(invulwaarde='K',
                              label='K',
                              status='ingebruik',
                              definitie='Kreukelpaal met arm',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLichtmastMasttype/K'),
        'KS': KeuzelijstWaarde(invulwaarde='KS',
                               label='KS',
                               status='ingebruik',
                               definitie='Kreukelpaal met arm op voet',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLichtmastMasttype/KS'),
        'M': KeuzelijstWaarde(invulwaarde='M',
                              label='M',
                              status='ingebruik',
                              definitie='Metalen paal met arm',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLichtmastMasttype/M'),
        'MS': KeuzelijstWaarde(invulwaarde='MS',
                               label='MS',
                               status='ingebruik',
                               definitie='Metalen paal met arm en voet',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLichtmastMasttype/MS'),
        'RK': KeuzelijstWaarde(invulwaarde='RK',
                               label='RK',
                               status='ingebruik',
                               definitie='Kreukelpaal',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLichtmastMasttype/RK'),
        'RKS': KeuzelijstWaarde(invulwaarde='RKS',
                                label='RKS',
                                status='ingebruik',
                                definitie='Kreukelpaal op voet',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLichtmastMasttype/RKS'),
        'RM': KeuzelijstWaarde(invulwaarde='RM',
                               label='RM',
                               status='ingebruik',
                               definitie='Rechte metalen paal',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLichtmastMasttype/RM'),
        'RMS': KeuzelijstWaarde(invulwaarde='RMS',
                                label='RMS',
                                status='ingebruik',
                                definitie='Rechte metalen paal op voet',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLichtmastMasttype/RMS')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlPositieSoort(KeuzelijstField):
    """Posities van het wegdek."""
    naam = 'KlPositieSoort'
    label = 'Positie soort'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlPositieSoort'
    definition = 'Posities van het wegdek.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlPositieSoort'
    options = {
        'linkerrand': KeuzelijstWaarde(invulwaarde='linkerrand',
                                       label='linkerrand',
                                       status='ingebruik',
                                       definitie='linkerrand',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPositieSoort/linkerrand'),
        'midden': KeuzelijstWaarde(invulwaarde='midden',
                                   label='midden',
                                   status='ingebruik',
                                   definitie='midden',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPositieSoort/midden'),
        'rechterrand': KeuzelijstWaarde(invulwaarde='rechterrand',
                                        label='rechterrand',
                                        status='ingebruik',
                                        definitie='rechterrand',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPositieSoort/rechterrand')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlRoosterOpeningswijze(KeuzelijstField):
    """Deze keuzelijst geeft de manier aan hoe het rooster geopend kan worden."""
    naam = 'KlRoosterOpeningswijze'
    label = 'Rooster openingswijze'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlRoosterOpeningswijze'
    definition = 'Deze keuzelijst geeft de manier aan hoe het rooster geopend kan worden.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlRoosterOpeningswijze'
    options = {
        'ovaal-deksel': KeuzelijstWaarde(invulwaarde='ovaal-deksel',
                                         label='ovaal deksel',
                                         status='ingebruik',
                                         definitie='ovaal deksel',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlRoosterOpeningswijze/ovaal-deksel'),
        'scharnierend': KeuzelijstWaarde(invulwaarde='scharnierend',
                                         label='scharnierend',
                                         status='ingebruik',
                                         definitie='scharnierend',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlRoosterOpeningswijze/scharnierend'),
        'uitneembaar': KeuzelijstWaarde(invulwaarde='uitneembaar',
                                        label='uitneembaar',
                                        status='ingebruik',
                                        definitie='uitneembaar',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlRoosterOpeningswijze/uitneembaar')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlElektromotorBouwvorm(KeuzelijstField):
    """Keuzelijst voor de bouwvorm van een elektromotor volgens de IM-code (International Mounting)."""
    naam = 'KlElektromotorBouwvorm'
    label = 'Elektromotor bouwvorm'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlElektromotorBouwvorm'
    definition = 'Keuzelijst voor de bouwvorm van een elektromotor volgens de IM-code (International Mounting).'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlElektromotorBouwvorm'
    options = {
        'im-b14---im-3601': KeuzelijstWaarde(invulwaarde='im-b14---im-3601',
                                             label='IM B14 / IM 3601',
                                             status='ingebruik',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlElektromotorBouwvorm/im-b14---im-3601'),
        'im-b3---im-1001': KeuzelijstWaarde(invulwaarde='im-b3---im-1001',
                                            label='IM B3 / IM 1001',
                                            status='ingebruik',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlElektromotorBouwvorm/im-b3---im-1001'),
        'im-b34---im-2101': KeuzelijstWaarde(invulwaarde='im-b34---im-2101',
                                             label='IM B34 / IM 2101',
                                             status='ingebruik',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlElektromotorBouwvorm/im-b34---im-2101'),
        'im-b35---im-2001': KeuzelijstWaarde(invulwaarde='im-b35---im-2001',
                                             label='IM B35 / IM 2001',
                                             status='ingebruik',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlElektromotorBouwvorm/im-b35---im-2001'),
        'im-b5---im-3001': KeuzelijstWaarde(invulwaarde='im-b5---im-3001',
                                            label='IM B5 / IM 3001',
                                            status='ingebruik',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlElektromotorBouwvorm/im-b5---im-3001'),
        'im-b6---im-1051': KeuzelijstWaarde(invulwaarde='im-b6---im-1051',
                                            label='IM B6 / IM 1051',
                                            status='ingebruik',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlElektromotorBouwvorm/im-b6---im-1051'),
        'im-b7---im-1061': KeuzelijstWaarde(invulwaarde='im-b7---im-1061',
                                            label='IM B7 / IM 1061',
                                            status='ingebruik',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlElektromotorBouwvorm/im-b7---im-1061'),
        'im-b8---im-1071': KeuzelijstWaarde(invulwaarde='im-b8---im-1071',
                                            label='IM B8 / IM 1071',
                                            status='ingebruik',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlElektromotorBouwvorm/im-b8---im-1071'),
        'im-v1---im-3011': KeuzelijstWaarde(invulwaarde='im-v1---im-3011',
                                            label='IM V1 / IM 3011',
                                            status='ingebruik',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlElektromotorBouwvorm/im-v1---im-3011'),
        'im-v15---im-2011': KeuzelijstWaarde(invulwaarde='im-v15---im-2011',
                                             label='IM V15 / IM 2011',
                                             status='ingebruik',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlElektromotorBouwvorm/im-v15---im-2011'),
        'im-v18---im-3611': KeuzelijstWaarde(invulwaarde='im-v18---im-3611',
                                             label='IM V18 / IM 3611',
                                             status='ingebruik',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlElektromotorBouwvorm/im-v18---im-3611'),
        'im-v19---im-3631': KeuzelijstWaarde(invulwaarde='im-v19---im-3631',
                                             label='IM V19 / IM 3631',
                                             status='ingebruik',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlElektromotorBouwvorm/im-v19---im-3631'),
        'im-v3---im-3031': KeuzelijstWaarde(invulwaarde='im-v3---im-3031',
                                            label='IM V3 / IM 3031',
                                            status='ingebruik',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlElektromotorBouwvorm/im-v3---im-3031'),
        'im-v36---im-2031': KeuzelijstWaarde(invulwaarde='im-v36---im-2031',
                                             label='IM V36 / IM 2031',
                                             status='ingebruik',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlElektromotorBouwvorm/im-v36---im-2031'),
        'im-v5---im-1011': KeuzelijstWaarde(invulwaarde='im-v5---im-1011',
                                            label='IM V5 / IM 1011',
                                            status='ingebruik',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlElektromotorBouwvorm/im-v5---im-1011'),
        'im-v6---im-1031': KeuzelijstWaarde(invulwaarde='im-v6---im-1031',
                                            label='IM V6 / IM 1031',
                                            status='ingebruik',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlElektromotorBouwvorm/im-v6---im-1031')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlPipeContainerType(KeuzelijstField):
    """Lijst met types van pies voor het oude AKELA-type Pipe."""
    naam = 'KlPipeContainerType'
    label = 'Pipe container type'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#KlPipeContainerType'
    definition = 'Lijst met types van pies voor het oude AKELA-type Pipe.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlPipeContainerType'
    options = {
        'kabelenleidinggoot': KeuzelijstWaarde(invulwaarde='kabelenleidinggoot',
                                               label='kabelEnLeidingGoot',
                                               status='ingebruik',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPipeContainerType/kabelenleidinggoot'),
        'mantelbuis': KeuzelijstWaarde(invulwaarde='mantelbuis',
                                       label='mantelbuis',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPipeContainerType/mantelbuis')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from typing import List
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from abc import abstractmethod
from otlmow_model.Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.Datatypes.DteIPv4Adres import DteIPv4Adres, DteIPv4AdresWaarden
from otlmow_model.Datatypes.KlHardwareCdDvdTape import KlHardwareCdDvdTape
from otlmow_model.Datatypes.KlHardwareDomein import KlHardwareDomein
from otlmow_model.Datatypes.KlHardwareOS import KlHardwareOS
from otlmow_model.Datatypes.KwantWrdInGigabyte import KwantWrdInGigabyte, KwantWrdInGigabyteWaarden
from otlmow_model.BaseClasses.StringField import StringField


# Generated with OTLClassCreator. To modify: extend, do not edit
class HardwareToegang(AIMNaamObject):
    """Een abstracte die de gemeenschappelijke kenmerken bevat voor zowel fysieke als virtuele hardware."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#HardwareToegang'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    @abstractmethod
    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#GPU')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#PCIKaart')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Netwerkpoort')

        self._CPU = OTLAttribuut(field=StringField,
                                 naam='CPU',
                                 label='CPU',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#HardwareToegang.CPU',
                                 definition='Centrale verwerkingseenheid.',
                                 owner=self)

        self._cdDvdTape = OTLAttribuut(field=KlHardwareCdDvdTape,
                                       naam='cdDvdTape',
                                       label='CD DVD Tape',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#HardwareToegang.cdDvdTape',
                                       definition='De hardware uitgerust met CD/DVD/Tape.',
                                       owner=self)

        self._disk = OTLAttribuut(field=KwantWrdInGigabyte,
                                  naam='disk',
                                  label='disk',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#HardwareToegang.disk',
                                  definition='De disk config van de hardware, HD, RAID, ...',
                                  owner=self)

        self._dnsNaam = OTLAttribuut(field=StringField,
                                     naam='dnsNaam',
                                     label='DNS naam',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#HardwareToegang.dnsNaam',
                                     definition='De DNSNaam (ook "volledige domein naam" genoemd ) is een unieke naam binnen het Domain Name System (DNS), het naamgevingssysteem waarmee computers, webservers, diensten en toepassing op een unieke manier kunnen worden geïdentificeerd. Deze bevat zowel de hostname en de top level domein naam bv. 120c8-ar1.belfa.be.',
                                     owner=self)

        self._domein = OTLAttribuut(field=KlHardwareDomein,
                                    naam='domein',
                                    label='domein',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#HardwareToegang.domein',
                                    definition='Administratieve groepering van meerdere particuliere computernetwerken of hosts binnen dezelfde infrastructuur.',
                                    owner=self)

        self._ipAdres = OTLAttribuut(field=DteIPv4Adres,
                                     naam='ipAdres',
                                     label='ip adres',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#HardwareToegang.ipAdres',
                                     kardinaliteit_max='*',
                                     definition='Het IP-adres van de hardware.',
                                     owner=self)

        self._licentie = OTLAttribuut(field=StringField,
                                      naam='licentie',
                                      label='licentie',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#HardwareToegang.licentie',
                                      definition='De licentie van het OS of de licentie van de hardware voor support/garantie op componenten.',
                                      owner=self)

        self._os = OTLAttribuut(field=KlHardwareOS,
                                naam='os',
                                label='OS',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#HardwareToegang.os',
                                definition='Het besturingssysteem dat op de hardware draait.',
                                owner=self)

        self._ram = OTLAttribuut(field=KwantWrdInGigabyte,
                                 naam='ram',
                                 label='RAM',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#HardwareToegang.ram',
                                 definition='De grootte van het werkgeheugen.',
                                 owner=self)

    @property
    def CPU(self) -> str:
        """Centrale verwerkingseenheid."""
        return self._CPU.get_waarde()

    @CPU.setter
    def CPU(self, value):
        self._CPU.set_waarde(value, owner=self)

    @property
    def cdDvdTape(self) -> str:
        """De hardware uitgerust met CD/DVD/Tape."""
        return self._cdDvdTape.get_waarde()

    @cdDvdTape.setter
    def cdDvdTape(self, value):
        self._cdDvdTape.set_waarde(value, owner=self)

    @property
    def disk(self) -> KwantWrdInGigabyteWaarden:
        """De disk config van de hardware, HD, RAID, ..."""
        return self._disk.get_waarde()

    @disk.setter
    def disk(self, value):
        self._disk.set_waarde(value, owner=self)

    @property
    def dnsNaam(self) -> str:
        """De DNSNaam (ook "volledige domein naam" genoemd ) is een unieke naam binnen het Domain Name System (DNS), het naamgevingssysteem waarmee computers, webservers, diensten en toepassing op een unieke manier kunnen worden geïdentificeerd. Deze bevat zowel de hostname en de top level domein naam bv. 120c8-ar1.belfa.be."""
        return self._dnsNaam.get_waarde()

    @dnsNaam.setter
    def dnsNaam(self, value):
        self._dnsNaam.set_waarde(value, owner=self)

    @property
    def domein(self) -> str:
        """Administratieve groepering van meerdere particuliere computernetwerken of hosts binnen dezelfde infrastructuur."""
        return self._domein.get_waarde()

    @domein.setter
    def domein(self, value):
        self._domein.set_waarde(value, owner=self)

    @property
    def ipAdres(self) -> List[DteIPv4AdresWaarden]:
        """Het IP-adres van de hardware."""
        return self._ipAdres.get_waarde()

    @ipAdres.setter
    def ipAdres(self, value):
        self._ipAdres.set_waarde(value, owner=self)

    @property
    def licentie(self) -> str:
        """De licentie van het OS of de licentie van de hardware voor support/garantie op componenten."""
        return self._licentie.get_waarde()

    @licentie.setter
    def licentie(self, value):
        self._licentie.set_waarde(value, owner=self)

    @property
    def os(self) -> str:
        """Het besturingssysteem dat op de hardware draait."""
        return self._os.get_waarde()

    @os.setter
    def os(self, value):
        self._os.set_waarde(value, owner=self)

    @property
    def ram(self) -> KwantWrdInGigabyteWaarden:
        """De grootte van het werkgeheugen."""
        return self._ram.get_waarde()

    @ram.setter
    def ram(self, value):
        self._ram.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from abc import abstractmethod
from otlmow_model.Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.BaseClasses.IntegerField import IntegerField
from otlmow_model.Datatypes.KlEnergiemeterMetertype import KlEnergiemeterMetertype
from otlmow_model.BaseClasses.StringField import StringField
from otlmow_model.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Energiemeter(AIMNaamObject, PuntGeometrie):
    """Abstracte voor alle energiemeters."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Energiemeter'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    @abstractmethod
    def __init__(self):
        AIMNaamObject.__init__(self)
        PuntGeometrie.__init__(self)

        self._aantalTelwerken = OTLAttribuut(field=IntegerField,
                                             naam='aantalTelwerken',
                                             label='aantal telwerken',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Energiemeter.aantalTelwerken',
                                             definition='Het aantal telwerken dat de energiemeter bevat: 1 bij enkelvoudige meter, 2 bij een dag- en nacht-meter.',
                                             owner=self)

        self._meternummer = OTLAttribuut(field=StringField,
                                         naam='meternummer',
                                         label='meternummer',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Energiemeter.meternummer',
                                         definition='Het serienummer (nummer van het fabrikaat) op de meter.',
                                         owner=self)

        self._metertype = OTLAttribuut(field=KlEnergiemeterMetertype,
                                       naam='metertype',
                                       label='metertype',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Energiemeter.metertype',
                                       definition='Type meter (mechanisch, elektronisch).',
                                       owner=self)

    @property
    def aantalTelwerken(self) -> int:
        """Het aantal telwerken dat de energiemeter bevat: 1 bij enkelvoudige meter, 2 bij een dag- en nacht-meter."""
        return self._aantalTelwerken.get_waarde()

    @aantalTelwerken.setter
    def aantalTelwerken(self, value):
        self._aantalTelwerken.set_waarde(value, owner=self)

    @property
    def meternummer(self) -> str:
        """Het serienummer (nummer van het fabrikaat) op de meter."""
        return self._meternummer.get_waarde()

    @meternummer.setter
    def meternummer(self, value):
        self._meternummer.set_waarde(value, owner=self)

    @property
    def metertype(self) -> str:
        """Type meter (mechanisch, elektronisch)."""
        return self._metertype.get_waarde()

    @metertype.setter
    def metertype(self, value):
        self._metertype.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from abc import abstractmethod
from otlmow_model.Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.Datatypes.KlKabelFabrikant import KlKabelFabrikant
from otlmow_model.Datatypes.KlKabelmantelKleur import KlKabelmantelKleur
from otlmow_model.Datatypes.KwantWrdInMillimeter import KwantWrdInMillimeter, KwantWrdInMillimeterWaarden
from otlmow_model.GeometrieTypes.LijnGeometrie import LijnGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Kabel(AIMNaamObject, LijnGeometrie):
    """Abstracte voor attributen en relaties van allerlei types kabels."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Kabel'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    @abstractmethod
    def __init__(self):
        AIMNaamObject.__init__(self)
        LijnGeometrie.__init__(self)

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Kabelmof')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HeeftAanvullendeGeometrie', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Onderdoorboring')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HeeftAanvullendeGeometrie', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Onderwaterkruising')

        self._buitenmantelDiameter = OTLAttribuut(field=KwantWrdInMillimeter,
                                                  naam='buitenmantelDiameter',
                                                  label='buitenmantel diameter',
                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Kabel.buitenmantelDiameter',
                                                  definition='De buitenste afmeting van de kabel in millimeter.',
                                                  owner=self)

        self._buitenmantelKleur = OTLAttribuut(field=KlKabelmantelKleur,
                                               naam='buitenmantelKleur',
                                               label='buitenmantel kleur',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Kabel.buitenmantelKleur',
                                               definition='De hoofdkleur(en) die voor een waarnemer onmiddellijk zichtbaar is (zijn) zonder de kabel te ontmantelen, de kleur van de markeringen op die buitenste mantel buiten beschouwing gelaten.',
                                               owner=self)

        self._fabrikant = OTLAttribuut(field=KlKabelFabrikant,
                                       naam='fabrikant',
                                       label='fabrikant',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Kabel.fabrikant',
                                       definition='De naam van de producent van de kabel.',
                                       owner=self)

    @property
    def buitenmantelDiameter(self) -> KwantWrdInMillimeterWaarden:
        """De buitenste afmeting van de kabel in millimeter."""
        return self._buitenmantelDiameter.get_waarde()

    @buitenmantelDiameter.setter
    def buitenmantelDiameter(self, value):
        self._buitenmantelDiameter.set_waarde(value, owner=self)

    @property
    def buitenmantelKleur(self) -> str:
        """De hoofdkleur(en) die voor een waarnemer onmiddellijk zichtbaar is (zijn) zonder de kabel te ontmantelen, de kleur van de markeringen op die buitenste mantel buiten beschouwing gelaten."""
        return self._buitenmantelKleur.get_waarde()

    @buitenmantelKleur.setter
    def buitenmantelKleur(self, value):
        self._buitenmantelKleur.set_waarde(value, owner=self)

    @property
    def fabrikant(self) -> str:
        """De naam van de producent van de kabel."""
        return self._fabrikant.get_waarde()

    @fabrikant.setter
    def fabrikant(self, value):
        self._fabrikant.set_waarde(value, owner=self)



# coding=utf-8
from typing import List
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.ImplementatieElement.AIMObject import AIMObject
from otlmow_model.BaseClasses.BooleanField import BooleanField
from otlmow_model.Datatypes.DtcMaaien import DtcMaaien, DtcMaaienWaarden
from otlmow_model.Datatypes.KlBeheerGrazigeVegetatie import KlBeheerGrazigeVegetatie
from otlmow_model.Datatypes.KwantWrdInMeter import KwantWrdInMeter, KwantWrdInMeterWaarden
from otlmow_model.Datatypes.KwantWrdInVierkanteMeter import KwantWrdInVierkanteMeter, KwantWrdInVierkanteMeterWaarden


# Generated with OTLClassCreator. To modify: extend, do not edit
class BeheerGrazigeVegetatie(AIMObject):
    """Het beheerobject voor de grazige vegetatie."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/levenscyclus#BeheerGrazigeVegetatie'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self._beheeroptie = OTLAttribuut(field=KlBeheerGrazigeVegetatie,
                                         naam='beheeroptie',
                                         label='beheeroptie',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/levenscyclus#BeheerGrazigeVegetatie.beheeroptie',
                                         kardinaliteit_max='*',
                                         definition='Aanduiding van welk beheer wordt toegepast op de grazige vegetatie.',
                                         owner=self)

        self._heeftBeheerplan = OTLAttribuut(field=BooleanField,
                                             naam='heeftBeheerplan',
                                             label='heeft beheerplan',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/levenscyclus#BeheerGrazigeVegetatie.heeftBeheerplan',
                                             definition='Aanduiding of er een beheerplan bestaat.',
                                             owner=self)

        self._lengte = OTLAttribuut(field=KwantWrdInMeter,
                                    naam='lengte',
                                    label='Lengte',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/levenscyclus#BeheerGrazigeVegetatie.lengte',
                                    definition='De lengte in meter van de te behandelen grazige vegetatie.',
                                    owner=self)

        self._maaien = OTLAttribuut(field=DtcMaaien,
                                    naam='maaien',
                                    label='maaien',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/levenscyclus#BeheerGrazigeVegetatie.maaien',
                                    definition='Complex datatype voor de eigenschappen van maaien.',
                                    owner=self)

        self._oppervlakte = OTLAttribuut(field=KwantWrdInVierkanteMeter,
                                         naam='oppervlakte',
                                         label='oppervlakte',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/levenscyclus#BeheerGrazigeVegetatie.oppervlakte',
                                         definition='De oppervlakte in vierkante meter van de te behandelen grazige vegetatie.',
                                         owner=self)

    @property
    def beheeroptie(self) -> List[str]:
        """Aanduiding van welk beheer wordt toegepast op de grazige vegetatie."""
        return self._beheeroptie.get_waarde()

    @beheeroptie.setter
    def beheeroptie(self, value):
        self._beheeroptie.set_waarde(value, owner=self)

    @property
    def heeftBeheerplan(self) -> bool:
        """Aanduiding of er een beheerplan bestaat."""
        return self._heeftBeheerplan.get_waarde()

    @heeftBeheerplan.setter
    def heeftBeheerplan(self, value):
        self._heeftBeheerplan.set_waarde(value, owner=self)

    @property
    def lengte(self) -> KwantWrdInMeterWaarden:
        """De lengte in meter van de te behandelen grazige vegetatie."""
        return self._lengte.get_waarde()

    @lengte.setter
    def lengte(self, value):
        self._lengte.set_waarde(value, owner=self)

    @property
    def maaien(self) -> DtcMaaienWaarden:
        """Complex datatype voor de eigenschappen van maaien."""
        return self._maaien.get_waarde()

    @maaien.setter
    def maaien(self, value):
        self._maaien.set_waarde(value, owner=self)

    @property
    def oppervlakte(self) -> KwantWrdInVierkanteMeterWaarden:
        """De oppervlakte in vierkante meter van de te behandelen grazige vegetatie."""
        return self._oppervlakte.get_waarde()

    @oppervlakte.setter
    def oppervlakte(self, value):
        self._oppervlakte.set_waarde(value, owner=self)



# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlCalamiteitsbordVorm(KeuzelijstField):
    """Vormen van het calamiteitsbord."""
    naam = 'KlCalamiteitsbordVorm'
    label = 'Calamiteitsbord vorm'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlCalamiteitsbordVorm'
    definition = 'Vormen van het calamiteitsbord.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlCalamiteitsbordVorm'
    options = {
        'rechthoekig': KeuzelijstWaarde(invulwaarde='rechthoekig',
                                        label='rechthoekig',
                                        status='ingebruik',
                                        definitie='Een rechthoekig calamiteitsbord.',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlCalamiteitsbordVorm/rechthoekig'),
        'ruitvormig': KeuzelijstWaarde(invulwaarde='ruitvormig',
                                       label='ruitvormig',
                                       status='ingebruik',
                                       definitie='Een ruitvormig calamiteitsbord.',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlCalamiteitsbordVorm/ruitvormig')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.Abstracten.ElektrischComponentennummerObject import ElektrischComponentennummerObject
from otlmow_model.Classes.Abstracten.FirmwareObject import FirmwareObject
from otlmow_model.Classes.Abstracten.SerienummerObject import SerienummerObject
from otlmow_model.Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.BaseClasses.BooleanField import BooleanField
from otlmow_model.Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from otlmow_model.Datatypes.KlAansluitingskabel import KlAansluitingskabel
from otlmow_model.Datatypes.KlBadgelezerMerk import KlBadgelezerMerk
from otlmow_model.Datatypes.KlBadgelezerModelnaam import KlBadgelezerModelnaam
from otlmow_model.Datatypes.KlBadgelezerProtocol import KlBadgelezerProtocol
from otlmow_model.Datatypes.KlEncryptieType import KlEncryptieType
from otlmow_model.BaseClasses.NonNegIntegerField import NonNegIntegerField


# Generated with OTLClassCreator. To modify: extend, do not edit
class Badgelezer(AIMNaamObject, ElektrischComponentennummerObject, FirmwareObject, SerienummerObject):
    """Een inrichting voor automatische authenticatie op basis van een badge."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Badgelezer'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        AIMNaamObject.__init__(self)
        ElektrischComponentennummerObject.__init__(self)
        FirmwareObject.__init__(self)
        SerienummerObject.__init__(self)

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Behuizing')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#BekledingComponent')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ConstructieElement')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#ZuilTGC')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Zoutbijlaadplaats')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Toegangscontroller')

        self._aansluitingskabel = OTLAttribuut(field=KlAansluitingskabel,
                                               naam='aansluitingskabel',
                                               label='aansluitingskabel',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Badgelezer.aansluitingskabel',
                                               definition='Geeft aan of er een kabel / welk type kabel er gebruikt wordt om communicatie van en naar dit element mogelijk te maken.',
                                               owner=self)

        self._aantalDraden = OTLAttribuut(field=NonNegIntegerField,
                                          naam='aantalDraden',
                                          label='aantal draden',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Badgelezer.aantalDraden',
                                          definition='Het aantal aders die door de kabel lopen.',
                                          owner=self)

        self._configuratiebestand = OTLAttribuut(field=DtcDocument,
                                                 naam='configuratiebestand',
                                                 label='configuratiebestand',
                                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Badgelezer.configuratiebestand',
                                                 definition='Bestand dat de configuratie gegevens van de badgelezer bijhoudt.',
                                                 owner=self)

        self._encryptieType = OTLAttribuut(field=KlEncryptieType,
                                           naam='encryptieType',
                                           label='encryptie type',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Badgelezer.encryptieType',
                                           definition='De type encryptie die de veiligheid van het dataverkeer tussen de badge en de badgelezer verzekert.',
                                           owner=self)

        self._heeftCodeklavier = OTLAttribuut(field=BooleanField,
                                              naam='heeftCodeklavier',
                                              label='heeft codeklavier',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Badgelezer.heeftCodeklavier',
                                              definition='Geeft aan of de badgelezer een geïntegreerd codeklavier heeft.',
                                              owner=self)

        self._heeftExtraVandalismebescherming = OTLAttribuut(field=BooleanField,
                                                             naam='heeftExtraVandalismebescherming',
                                                             label='heeft extra vandalismebescherming',
                                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Badgelezer.heeftExtraVandalismebescherming',
                                                             definition='Geeft aan of de badgelezer voorzien is van additionele vandalismebescherming.',
                                                             owner=self)

        self._heeftQRCodelezer = OTLAttribuut(field=BooleanField,
                                              naam='heeftQRCodelezer',
                                              label='heeft QR codelezer',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Badgelezer.heeftQRCodelezer',
                                              definition='Geeft aan of de badgelezer een inrichting heeft om QR codes te lezen die integraal deel uitmaakt van de badgelzer zelf.',
                                              owner=self)

        self._isBuiten = OTLAttribuut(field=BooleanField,
                                      naam='isBuiten',
                                      label='is buiten',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Badgelezer.isBuiten',
                                      definition='Geeft aan of de badgelezer zich binnen of buiten bevindt.',
                                      owner=self)

        self._merk = OTLAttribuut(field=KlBadgelezerMerk,
                                  naam='merk',
                                  label='merk',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Badgelezer.merk',
                                  definition='Het merk van de badgelezer.',
                                  owner=self)

        self._modelnaam = OTLAttribuut(field=KlBadgelezerModelnaam,
                                       naam='modelnaam',
                                       label='modelnaam',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Badgelezer.modelnaam',
                                       definition='De modelnaam van de badgelezer.',
                                       owner=self)

        self._protocol = OTLAttribuut(field=KlBadgelezerProtocol,
                                      naam='protocol',
                                      label='protocol',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Badgelezer.protocol',
                                      definition='Het protocol gebruikt door de badgelezer om gegevens mee te sturen en ontvangen.',
                                      owner=self)

        self._technischeFiche = OTLAttribuut(field=DtcDocument,
                                             naam='technischeFiche',
                                             label='technische fiche',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Badgelezer.technischeFiche',
                                             definition='De technische fiche van een badgelezer.',
                                             owner=self)

    @property
    def aansluitingskabel(self) -> str:
        """Geeft aan of er een kabel / welk type kabel er gebruikt wordt om communicatie van en naar dit element mogelijk te maken."""
        return self._aansluitingskabel.get_waarde()

    @aansluitingskabel.setter
    def aansluitingskabel(self, value):
        self._aansluitingskabel.set_waarde(value, owner=self)

    @property
    def aantalDraden(self) -> int:
        """Het aantal aders die door de kabel lopen."""
        return self._aantalDraden.get_waarde()

    @aantalDraden.setter
    def aantalDraden(self, value):
        self._aantalDraden.set_waarde(value, owner=self)

    @property
    def configuratiebestand(self) -> DtcDocumentWaarden:
        """Bestand dat de configuratie gegevens van de badgelezer bijhoudt."""
        return self._configuratiebestand.get_waarde()

    @configuratiebestand.setter
    def configuratiebestand(self, value):
        self._configuratiebestand.set_waarde(value, owner=self)

    @property
    def encryptieType(self) -> str:
        """De type encryptie die de veiligheid van het dataverkeer tussen de badge en de badgelezer verzekert."""
        return self._encryptieType.get_waarde()

    @encryptieType.setter
    def encryptieType(self, value):
        self._encryptieType.set_waarde(value, owner=self)

    @property
    def heeftCodeklavier(self) -> bool:
        """Geeft aan of de badgelezer een geïntegreerd codeklavier heeft."""
        return self._heeftCodeklavier.get_waarde()

    @heeftCodeklavier.setter
    def heeftCodeklavier(self, value):
        self._heeftCodeklavier.set_waarde(value, owner=self)

    @property
    def heeftExtraVandalismebescherming(self) -> bool:
        """Geeft aan of de badgelezer voorzien is van additionele vandalismebescherming."""
        return self._heeftExtraVandalismebescherming.get_waarde()

    @heeftExtraVandalismebescherming.setter
    def heeftExtraVandalismebescherming(self, value):
        self._heeftExtraVandalismebescherming.set_waarde(value, owner=self)

    @property
    def heeftQRCodelezer(self) -> bool:
        """Geeft aan of de badgelezer een inrichting heeft om QR codes te lezen die integraal deel uitmaakt van de badgelzer zelf."""
        return self._heeftQRCodelezer.get_waarde()

    @heeftQRCodelezer.setter
    def heeftQRCodelezer(self, value):
        self._heeftQRCodelezer.set_waarde(value, owner=self)

    @property
    def isBuiten(self) -> bool:
        """Geeft aan of de badgelezer zich binnen of buiten bevindt."""
        return self._isBuiten.get_waarde()

    @isBuiten.setter
    def isBuiten(self, value):
        self._isBuiten.set_waarde(value, owner=self)

    @property
    def merk(self) -> str:
        """Het merk van de badgelezer."""
        return self._merk.get_waarde()

    @merk.setter
    def merk(self, value):
        self._merk.set_waarde(value, owner=self)

    @property
    def modelnaam(self) -> str:
        """De modelnaam van de badgelezer."""
        return self._modelnaam.get_waarde()

    @modelnaam.setter
    def modelnaam(self, value):
        self._modelnaam.set_waarde(value, owner=self)

    @property
    def protocol(self) -> str:
        """Het protocol gebruikt door de badgelezer om gegevens mee te sturen en ontvangen."""
        return self._protocol.get_waarde()

    @protocol.setter
    def protocol(self, value):
        self._protocol.set_waarde(value, owner=self)

    @property
    def technischeFiche(self) -> DtcDocumentWaarden:
        """De technische fiche van een badgelezer."""
        return self._technischeFiche.get_waarde()

    @technischeFiche.setter
    def technischeFiche(self, value):
        self._technischeFiche.set_waarde(value, owner=self)



# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlIOSignaaltype(KeuzelijstField):
    """Geeft aan of de IO-kaart werkt met een digitaal of met een analoog signaal."""
    naam = 'KlIOSignaaltype'
    label = 'IO-kaart signaaltype'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlIOSignaaltype'
    definition = 'Geeft aan of de IO-kaart werkt met een digitaal of met een analoog signaal.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlIOSignaaltype'
    options = {
        'analoog': KeuzelijstWaarde(invulwaarde='analoog',
                                    label='analoog',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlIOSignaaltype/analoog'),
        'digitaal': KeuzelijstWaarde(invulwaarde='digitaal',
                                     label='digitaal',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlIOSignaaltype/digitaal')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlAfmetingsensorModelnaam(KeuzelijstField):
    """De modelnaam van de afmetingsensor."""
    naam = 'KlAfmetingsensorModelnaam'
    label = 'Afmetingsensor modelnaam'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlAfmetingsensorModelnaam'
    definition = 'De modelnaam van de afmetingsensor.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlAfmetingsensorModelnaam'
    options = {
        'FPS': KeuzelijstWaarde(invulwaarde='FPS',
                                label='FPS',
                                status='ingebruik',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAfmetingsensorModelnaam/FPS'),
        'LMS': KeuzelijstWaarde(invulwaarde='LMS',
                                label='LMS',
                                status='ingebruik',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAfmetingsensorModelnaam/LMS')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from abc import abstractmethod
from otlmow_model.Classes.ImplementatieElement.AIMObject import AIMObject


# Generated with OTLClassCreator. To modify: extend, do not edit
class Proef(AIMObject):
    """Abstracte voor de gemeenschappelijke eigenschappen en relaties alle proeven."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Proef'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    @abstractmethod
    def __init__(self):
        super().__init__()



# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.Abstracten.Proef import Proef
from otlmow_model.Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from otlmow_model.GeometrieTypes.PuntGeometrie import PuntGeometrie
from otlmow_model.GeometrieTypes.LijnGeometrie import LijnGeometrie
from otlmow_model.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class ProefStroefheid(Proef, PuntGeometrie, LijnGeometrie, VlakGeometrie):
    """Het vermogen van een wegdek om door voertuigbanden tangentieel uitgeoefende krachten (bij het nemen van bochten, afremmen of optrekken) te compenseren door even grote wrijvingskrachten."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefStroefheid'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        Proef.__init__(self)
        LijnGeometrie.__init__(self)
        PuntGeometrie.__init__(self)
        VlakGeometrie.__init__(self)

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Markering')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bestrijking')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Cementbetonverharding')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DunneOverlaging')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Slemlaag')

        self._stroefheid = OTLAttribuut(field=DtcDocument,
                                        naam='stroefheid',
                                        label='stroefheid',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefStroefheid.stroefheid',
                                        definition='Proefresultaten van de stroefheid.',
                                        owner=self)

    @property
    def stroefheid(self) -> DtcDocumentWaarden:
        """Proefresultaten van de stroefheid."""
        return self._stroefheid.get_waarde()

    @stroefheid.setter
    def stroefheid(self, value):
        self._stroefheid.set_waarde(value, owner=self)



# coding=utf-8
from typing import List
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.ImplementatieElement.AIMObject import AIMObject
from otlmow_model.Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from otlmow_model.Datatypes.KwantWrdInMeter import KwantWrdInMeter, KwantWrdInMeterWaarden
from otlmow_model.Datatypes.KwantWrdInVierkanteMeter import KwantWrdInVierkanteMeter, KwantWrdInVierkanteMeterWaarden
from otlmow_model.GeometrieTypes.LijnGeometrie import LijnGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class GeluidwerendeConstructie(AIMObject, LijnGeometrie):
    """Een geluidswerende wandvormige constructie bestaande uit een desgevallend geluidsisolerend materiaal en/of geluidsabsorberend materiaal en voorzien van de nodige structuren om de bouwkundige stabiliteit te verzekeren."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#GeluidwerendeConstructie'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        AIMObject.__init__(self)
        LijnGeometrie.__init__(self)

        self._detailplanHoogteverloop = OTLAttribuut(field=DtcDocument,
                                                     naam='detailplanHoogteverloop',
                                                     label='detailplan hoogteverloop',
                                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#GeluidwerendeConstructie.detailplanHoogteverloop',
                                                     usagenote='Bestanden moeten van het type DWG of DXF zijn.',
                                                     definition='Dit is een detailplan in de vorm van een lijn waarin het verloop van de absolute hoogte van de top van de geluidswerende constructie wordt weergegeven. Minstens om de 10 meter wordt de hoogte van de top van de constructie bepaald. Het detailplan wordt gebruikt voor akoestische modellering.',
                                                     owner=self)

        self._horizontaalRuimtebeslag = OTLAttribuut(field=DtcDocument,
                                                     naam='horizontaalRuimtebeslag',
                                                     label='horizontaal ruimtebeslag',
                                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#GeluidwerendeConstructie.horizontaalRuimtebeslag',
                                                     definition='Document waarin de variatie in horizontaal ruimtebeslag over het verloop van de geluidswerende constructie is weergegeven. Het horizontaal ruimtebeslag is de breedte die de gehele constructie inneemt op het maaiveld, loodrecht op de richting waarin de schermelementen op elkaar aangesloten zijn. Er moet een nieuwe waarde ingegeven worden elke keer als de hoogte van de constructie wijzigt.',
                                                     owner=self)

        self._overzichtsafbeelding = OTLAttribuut(field=DtcDocument,
                                                  naam='overzichtsafbeelding',
                                                  label='overzichtsafbeelding',
                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#GeluidwerendeConstructie.overzichtsafbeelding',
                                                  kardinaliteit_max='*',
                                                  definition='Dit een overzichtsfoto van de hele constructie. Op basis van deze afbeelding kan je snel bekijken hoe de kleur of hoogte varieert over het verloop van de geluidswerende constructie.',
                                                  owner=self)

        self._rekennota = OTLAttribuut(field=DtcDocument,
                                       naam='rekennota',
                                       label='rekennota',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#GeluidwerendeConstructie.rekennota',
                                       kardinaliteit_max='*',
                                       definition='Dit is een document waarin allerlei berekeningen bijgehouden worden omtrent de stabiliteit en sterkte van de geluidswerende constructie (oa de variatie in statische belasting en windbelasting over het verloop van geluidswerende constructie).',
                                       owner=self)

        self._technischeFiche = OTLAttribuut(field=DtcDocument,
                                             naam='technischeFiche',
                                             label='technische fiche',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#GeluidwerendeConstructie.technischeFiche',
                                             kardinaliteit_max='*',
                                             definition='Dit document geeft volgende zaken mee: producent, productnaam (type), beschrijving van de geplaatste constructie, certificatie (CE en ISO), montage, akoestische karakteristieken, duurzaamheid en brandwerende kenmerken.',
                                             owner=self)

        self._totaleLengte = OTLAttribuut(field=KwantWrdInMeter,
                                          naam='totaleLengte',
                                          label='totale lengte',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#GeluidwerendeConstructie.totaleLengte',
                                          definition='De afstand in meter gemeten tussen het beginpunt en het eindpunt van de geluidswerende constructie.',
                                          owner=self)

        self._totaleOppervlakte = OTLAttribuut(field=KwantWrdInVierkanteMeter,
                                               naam='totaleOppervlakte',
                                               label='totale oppervlakte',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#GeluidwerendeConstructie.totaleOppervlakte',
                                               definition='De totale oppervlakte van het naar de weg gerichte vlak van alle geplaatste schermelementen van de geluidswerende constructie.',
                                               owner=self)

    @property
    def detailplanHoogteverloop(self) -> DtcDocumentWaarden:
        """Dit is een detailplan in de vorm van een lijn waarin het verloop van de absolute hoogte van de top van de geluidswerende constructie wordt weergegeven. Minstens om de 10 meter wordt de hoogte van de top van de constructie bepaald. Het detailplan wordt gebruikt voor akoestische modellering."""
        return self._detailplanHoogteverloop.get_waarde()

    @detailplanHoogteverloop.setter
    def detailplanHoogteverloop(self, value):
        self._detailplanHoogteverloop.set_waarde(value, owner=self)

    @property
    def horizontaalRuimtebeslag(self) -> DtcDocumentWaarden:
        """Document waarin de variatie in horizontaal ruimtebeslag over het verloop van de geluidswerende constructie is weergegeven. Het horizontaal ruimtebeslag is de breedte die de gehele constructie inneemt op het maaiveld, loodrecht op de richting waarin de schermelementen op elkaar aangesloten zijn. Er moet een nieuwe waarde ingegeven worden elke keer als de hoogte van de constructie wijzigt."""
        return self._horizontaalRuimtebeslag.get_waarde()

    @horizontaalRuimtebeslag.setter
    def horizontaalRuimtebeslag(self, value):
        self._horizontaalRuimtebeslag.set_waarde(value, owner=self)

    @property
    def overzichtsafbeelding(self) -> List[DtcDocumentWaarden]:
        """Dit een overzichtsfoto van de hele constructie. Op basis van deze afbeelding kan je snel bekijken hoe de kleur of hoogte varieert over het verloop van de geluidswerende constructie."""
        return self._overzichtsafbeelding.get_waarde()

    @overzichtsafbeelding.setter
    def overzichtsafbeelding(self, value):
        self._overzichtsafbeelding.set_waarde(value, owner=self)

    @property
    def rekennota(self) -> List[DtcDocumentWaarden]:
        """Dit is een document waarin allerlei berekeningen bijgehouden worden omtrent de stabiliteit en sterkte van de geluidswerende constructie (oa de variatie in statische belasting en windbelasting over het verloop van geluidswerende constructie)."""
        return self._rekennota.get_waarde()

    @rekennota.setter
    def rekennota(self, value):
        self._rekennota.set_waarde(value, owner=self)

    @property
    def technischeFiche(self) -> List[DtcDocumentWaarden]:
        """Dit document geeft volgende zaken mee: producent, productnaam (type), beschrijving van de geplaatste constructie, certificatie (CE en ISO), montage, akoestische karakteristieken, duurzaamheid en brandwerende kenmerken."""
        return self._technischeFiche.get_waarde()

    @technischeFiche.setter
    def technischeFiche(self, value):
        self._technischeFiche.set_waarde(value, owner=self)

    @property
    def totaleLengte(self) -> KwantWrdInMeterWaarden:
        """De afstand in meter gemeten tussen het beginpunt en het eindpunt van de geluidswerende constructie."""
        return self._totaleLengte.get_waarde()

    @totaleLengte.setter
    def totaleLengte(self, value):
        self._totaleLengte.set_waarde(value, owner=self)

    @property
    def totaleOppervlakte(self) -> KwantWrdInVierkanteMeterWaarden:
        """De totale oppervlakte van het naar de weg gerichte vlak van alle geplaatste schermelementen van de geluidswerende constructie."""
        return self._totaleOppervlakte.get_waarde()

    @totaleOppervlakte.setter
    def totaleOppervlakte(self, value):
        self._totaleOppervlakte.set_waarde(value, owner=self)



from otlmow_model.BaseClasses.WaardenObject import WaardenObject


class UnionWaarden(WaardenObject):
    def __init__(self):
        WaardenObject.__init__(self)

    def clear_other_props(self, prop_name):
        other_prop_keys = list(filter(lambda x: x != prop_name, vars(self).keys()))
        for key in other_prop_keys:
            if key == '_parent' or key[0] != '_':
                continue
            attr = getattr(self, key)
            if attr.field.waardeObject is not None and not attr.field.waarde_shortcut_applicable:
                attr = getattr(self, key[1:])
                setattr(attr, 'waarde', None)
            else:
                setattr(self, key[1:], None)


# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlSignalisatieMarkeringOpvatting(KeuzelijstField):
    """De markeringsopvattingen van de markering."""
    naam = 'KlSignalisatieMarkeringOpvatting'
    label = 'Signalisatie markering opvatting'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlSignalisatieMarkeringOpvatting'
    definition = 'De markeringsopvattingen van de markering.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlSignalisatieMarkeringOpvatting'
    options = {
        'middelenverbintenis': KeuzelijstWaarde(invulwaarde='middelenverbintenis',
                                                label='middelenverbintenis',
                                                status='ingebruik',
                                                definitie='Legt de nadruk op de wijze van aanbrengen en doseringen.',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignalisatieMarkeringOpvatting/middelenverbintenis'),
        'resultaatsverbintenis': KeuzelijstWaarde(invulwaarde='resultaatsverbintenis',
                                                  label='resultaatsverbintenis',
                                                  status='ingebruik',
                                                  definitie='Houdt in dat de doseringen niet worden vastgelegd in het bijzonder bestek maar dat de markeringen, in nieuwe toestand en gedurende de waarborgperiode voor de markering, moeten voldoen aan resultaatseisen. ',
                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSignalisatieMarkeringOpvatting/resultaatsverbintenis')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlMasttypePunctueleVerlichting(KeuzelijstField):
    """Het type van de mast voor punctuele verlichting."""
    naam = 'KlMasttypePunctueleVerlichting'
    label = 'Masttype voor punctuele verlichting'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlMasttypePunctueleVerlichting'
    definition = 'Het type van de mast voor punctuele verlichting.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlMasttypePunctueleVerlichting'
    options = {
        'mt': KeuzelijstWaarde(invulwaarde='mt',
                               label='MT',
                               status='ingebruik',
                               definitie='Metalen galgmast voor punctuele verlichting met inplantingsstuk.',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlMasttypePunctueleVerlichting/mt'),
        'mts': KeuzelijstWaarde(invulwaarde='mts',
                                label='MTS',
                                status='ingebruik',
                                definitie='Metalen galgmast voor punctuele verlichting op voetplaat.',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlMasttypePunctueleVerlichting/mts')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlBuisbekledingUitvoeringswijze(KeuzelijstField):
    """Materiaal en manier van aanbrengen van de buisbekleding."""
    naam = 'KlBuisbekledingUitvoeringswijze'
    label = 'uitvoeringswijze buisbekleding'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlBuisbekledingUitvoeringswijze'
    definition = 'Materiaal en manier van aanbrengen van de buisbekleding.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlBuisbekledingUitvoeringswijze'
    options = {
        'bouwput-voor-rioolrenovatie-dmv-buis-in-buissysteem-met-glasvezelversterkte-polyesterelementen': KeuzelijstWaarde(invulwaarde='bouwput-voor-rioolrenovatie-dmv-buis-in-buissysteem-met-glasvezelversterkte-polyesterelementen',
                                                                                                                           label='bouwput voor rioolrenovatie dmv buis in buissysteem met glasvezelversterkte polyesterelementen',
                                                                                                                           status='ingebruik',
                                                                                                                           definitie='Bouwput voor rioolrenovatie dmv buis in buissysteem met glasvezelversterkte polyesterelementen',
                                                                                                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/bouwput-voor-rioolrenovatie-dmv-buis-in-buissysteem-met-glasvezelversterkte-polyesterelementen'),
        'buis-in-buis-renovatie-met-hard-PVC-wikkelbuizen.-profiel-nr.-140': KeuzelijstWaarde(invulwaarde='buis-in-buis-renovatie-met-hard-PVC-wikkelbuizen.-profiel-nr.-140',
                                                                                              label='buis in buis renovatie met hard-PVC-wikkelbuizen. profiel nr. 140',
                                                                                              status='ingebruik',
                                                                                              definitie='Buis in buis renovatie met hard-PVC-wikkelbuizen, profiel nr. 140',
                                                                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/buis-in-buis-renovatie-met-hard-PVC-wikkelbuizen.-profiel-nr.-140'),
        'buis-in-buis-renovatie-met-hard-PVC-wikkelbuizen.-profiel-nr.-50': KeuzelijstWaarde(invulwaarde='buis-in-buis-renovatie-met-hard-PVC-wikkelbuizen.-profiel-nr.-50',
                                                                                             label='buis in buis renovatie met hard-PVC-wikkelbuizen. profiel nr. 50',
                                                                                             status='ingebruik',
                                                                                             definitie='Buis in buis renovatie met hard-PVC-wikkelbuizen, profiel nr. 50',
                                                                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/buis-in-buis-renovatie-met-hard-PVC-wikkelbuizen.-profiel-nr.-50'),
        'buis-in-buis-renovatie-met-hard-PVC-wikkelbuizen.-profiel-nr.-60': KeuzelijstWaarde(invulwaarde='buis-in-buis-renovatie-met-hard-PVC-wikkelbuizen.-profiel-nr.-60',
                                                                                             label='buis in buis renovatie met hard-PVC-wikkelbuizen. profiel nr. 60',
                                                                                             status='ingebruik',
                                                                                             definitie='Buis in buis renovatie met hard-PVC-wikkelbuizen, profiel nr. 60',
                                                                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/buis-in-buis-renovatie-met-hard-PVC-wikkelbuizen.-profiel-nr.-60'),
        'buis-in-buis-renovatie-met-hard-PVC-wikkelbuizen.-profiel-nr.-90': KeuzelijstWaarde(invulwaarde='buis-in-buis-renovatie-met-hard-PVC-wikkelbuizen.-profiel-nr.-90',
                                                                                             label='buis in buis renovatie met hard-PVC-wikkelbuizen. profiel nr. 90',
                                                                                             status='ingebruik',
                                                                                             definitie='Buis in buis renovatie met hard-PVC-wikkelbuizen, profiel nr. 90',
                                                                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/buis-in-buis-renovatie-met-hard-PVC-wikkelbuizen.-profiel-nr.-90'),
        'buis-in-buis-renovatie-met-standaardbuizen-in-GVP.-sterktereeks-SN-10000-N-mm2': KeuzelijstWaarde(invulwaarde='buis-in-buis-renovatie-met-standaardbuizen-in-GVP.-sterktereeks-SN-10000-N-mm2',
                                                                                                           label='buis in buis renovatie met standaardbuizen in GVP. sterktereeks SN 10000 N-mm2',
                                                                                                           status='ingebruik',
                                                                                                           definitie='Buis in buis renovatie met standaardbuizen in GVP, sterktereeks SN 10000 N/mm2',
                                                                                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/buis-in-buis-renovatie-met-standaardbuizen-in-GVP.-sterktereeks-SN-10000-N-mm2'),
        'buis-in-buis-renovatie-met-standaardbuizen-in-GVP.-sterktereeks-SN-2500-N-mm2': KeuzelijstWaarde(invulwaarde='buis-in-buis-renovatie-met-standaardbuizen-in-GVP.-sterktereeks-SN-2500-N-mm2',
                                                                                                          label='buis in buis renovatie met standaardbuizen in GVP. sterktereeks SN 2500 N-mm2',
                                                                                                          status='ingebruik',
                                                                                                          definitie='Buis in buis renovatie met standaardbuizen in GVP, sterktereeks SN 2500 N/mm2',
                                                                                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/buis-in-buis-renovatie-met-standaardbuizen-in-GVP.-sterktereeks-SN-2500-N-mm2'),
        'buis-in-buis-renovatie-met-standaardbuizen-in-GVP.-sterktereeks-SN-5000-N-mm2': KeuzelijstWaarde(invulwaarde='buis-in-buis-renovatie-met-standaardbuizen-in-GVP.-sterktereeks-SN-5000-N-mm2',
                                                                                                          label='buis in buis renovatie met standaardbuizen in GVP. sterktereeks SN 5000 N-mm2',
                                                                                                          status='ingebruik',
                                                                                                          definitie='Buis in buis renovatie met standaardbuizen in GVP, sterktereeks SN 5000 N/mm2',
                                                                                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/buis-in-buis-renovatie-met-standaardbuizen-in-GVP.-sterktereeks-SN-5000-N-mm2'),
        'buis-in-buis-renovatie.-met-wandversterkte-HDPE-buizen': KeuzelijstWaarde(invulwaarde='buis-in-buis-renovatie.-met-wandversterkte-HDPE-buizen',
                                                                                   label='buis in buis renovatie. met wandversterkte HDPE-buizen',
                                                                                   status='ingebruik',
                                                                                   definitie='Buis in buis renovatie, met wandversterkte HDPE-buizen',
                                                                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/buis-in-buis-renovatie.-met-wandversterkte-HDPE-buizen'),
        'gunitage-via-de-natte-spuitmethode.-met-wapening.-glad-oppervlak': KeuzelijstWaarde(invulwaarde='gunitage-via-de-natte-spuitmethode.-met-wapening.-glad-oppervlak',
                                                                                             label='gunitage via de natte spuitmethode. met wapening. glad oppervlak',
                                                                                             status='ingebruik',
                                                                                             definitie='Gunitage via de natte spuitmethode, met wapening, glad oppervlak',
                                                                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/gunitage-via-de-natte-spuitmethode.-met-wapening.-glad-oppervlak'),
        'gunitage-via-de-natte-spuitmethode.-met-wapening.-ruw-oppervlak': KeuzelijstWaarde(invulwaarde='gunitage-via-de-natte-spuitmethode.-met-wapening.-ruw-oppervlak',
                                                                                            label='gunitage via de natte spuitmethode. met wapening. ruw oppervlak',
                                                                                            status='ingebruik',
                                                                                            definitie='Gunitage via de natte spuitmethode, met wapening, ruw oppervlak',
                                                                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/gunitage-via-de-natte-spuitmethode.-met-wapening.-ruw-oppervlak'),
        'gunitage-via-de-natte-spuitmethode.-zonder-wapening.-glad-oppervlak': KeuzelijstWaarde(invulwaarde='gunitage-via-de-natte-spuitmethode.-zonder-wapening.-glad-oppervlak',
                                                                                                label='gunitage via de natte spuitmethode. zonder wapening. glad oppervlak',
                                                                                                status='ingebruik',
                                                                                                definitie='Gunitage via de natte spuitmethode, zonder wapening, glad oppervlak',
                                                                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/gunitage-via-de-natte-spuitmethode.-zonder-wapening.-glad-oppervlak'),
        'gunitage-via-de-natte-spuitmethode.-zonder-wapening.-ruw-oppervlak': KeuzelijstWaarde(invulwaarde='gunitage-via-de-natte-spuitmethode.-zonder-wapening.-ruw-oppervlak',
                                                                                               label='gunitage via de natte spuitmethode. zonder wapening. ruw oppervlak',
                                                                                               status='ingebruik',
                                                                                               definitie='Gunitage via de natte spuitmethode, zonder wapening, ruw oppervlak',
                                                                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/gunitage-via-de-natte-spuitmethode.-zonder-wapening.-ruw-oppervlak'),
        'herstelling-van-lekkende-voegverbindingen-en-grindnesten-door-middel-van-het-plaatsen-van-inox-manchetten-in-buisleidingen': KeuzelijstWaarde(invulwaarde='herstelling-van-lekkende-voegverbindingen-en-grindnesten-door-middel-van-het-plaatsen-van-inox-manchetten-in-buisleidingen',
                                                                                                                                                       label='herstelling van lekkende voegverbindingen en grindnesten door middel van het plaatsen van inox manchetten in buisleidingen',
                                                                                                                                                       status='ingebruik',
                                                                                                                                                       definitie='Herstelling van lekkende voegverbindingen en grindnesten door middel van het plaatsen van inox manchetten in buisleidingen',
                                                                                                                                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/herstelling-van-lekkende-voegverbindingen-en-grindnesten-door-middel-van-het-plaatsen-van-inox-manchetten-in-buisleidingen'),
        'inwendige-bekleding-met-PUR-verf-voor-buizen-van-nodulair-gietijzer': KeuzelijstWaarde(invulwaarde='inwendige-bekleding-met-PUR-verf-voor-buizen-van-nodulair-gietijzer',
                                                                                                label='inwendige bekleding met PUR-verf voor buizen van nodulair gietijzer',
                                                                                                status='ingebruik',
                                                                                                definitie='inwendige bekleding met PUR-verf voor buizen van nodC3:C48ulair gietijzer',
                                                                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/inwendige-bekleding-met-PUR-verf-voor-buizen-van-nodulair-gietijzer'),
        'pipebursting': KeuzelijstWaarde(invulwaarde='pipebursting',
                                         label='pipebursting',
                                         status='ingebruik',
                                         definitie='pipebursting',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/pipebursting'),
        'renovatie-door-lining-met-TUB-met-structureel-onvoldoende-reststerkte': KeuzelijstWaarde(invulwaarde='renovatie-door-lining-met-TUB-met-structureel-onvoldoende-reststerkte',
                                                                                                  label='renovatie door lining met TUB met structureel onvoldoende reststerkte',
                                                                                                  status='ingebruik',
                                                                                                  definitie='Renovatie door lining met TUB met structureel onvoldoende reststerkte',
                                                                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/renovatie-door-lining-met-TUB-met-structureel-onvoldoende-reststerkte'),
        'renovatie-door-lining-met-TUB-met-structureel-voldoende-reststerkte': KeuzelijstWaarde(invulwaarde='renovatie-door-lining-met-TUB-met-structureel-voldoende-reststerkte',
                                                                                                label='renovatie door lining met TUB met structureel voldoende reststerkte',
                                                                                                status='ingebruik',
                                                                                                definitie='Renovatie door lining met TUB met structureel voldoende reststerkte',
                                                                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/renovatie-door-lining-met-TUB-met-structureel-voldoende-reststerkte'),
        'renovatie-door-middel-van-solventvrije-vezelversterkte-kunstharsen': KeuzelijstWaarde(invulwaarde='renovatie-door-middel-van-solventvrije-vezelversterkte-kunstharsen',
                                                                                               label='renovatie door middel van solventvrije vezelversterkte kunstharsen',
                                                                                               status='ingebruik',
                                                                                               definitie='Renovatie door middel van solventvrije vezelversterkte kunstharsen',
                                                                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/renovatie-door-middel-van-solventvrije-vezelversterkte-kunstharsen'),
        'renovatie-stroomprofiel-met-buis-in-buissysteem-met-GVP-elementen': KeuzelijstWaarde(invulwaarde='renovatie-stroomprofiel-met-buis-in-buissysteem-met-GVP-elementen',
                                                                                              label='renovatie stroomprofiel met buis in buissysteem met GVP-elementen',
                                                                                              status='ingebruik',
                                                                                              definitie='Renovatie stroomprofiel met buis in buissysteem met GVP-elementen',
                                                                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/renovatie-stroomprofiel-met-buis-in-buissysteem-met-GVP-elementen'),
        'renovatie-stroomprofiel-met-buis-in-buissysteem-met-GVP-panelen': KeuzelijstWaarde(invulwaarde='renovatie-stroomprofiel-met-buis-in-buissysteem-met-GVP-panelen',
                                                                                            label='renovatie stroomprofiel met buis in buissysteem met GVP-panelen',
                                                                                            status='ingebruik',
                                                                                            definitie='Renovatie stroomprofiel met buis in buissysteem met GVP-panelen',
                                                                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/renovatie-stroomprofiel-met-buis-in-buissysteem-met-GVP-panelen'),
        'renovatie-volledige-leidingsectie-met-buis-in-buissysteem-met-GVP-elementen': KeuzelijstWaarde(invulwaarde='renovatie-volledige-leidingsectie-met-buis-in-buissysteem-met-GVP-elementen',
                                                                                                        label='renovatie volledige leidingsectie met buis in buissysteem met GVP-elementen',
                                                                                                        status='ingebruik',
                                                                                                        definitie='Renovatie volledige leidingsectie met buis in buissysteem met GVP-elementen',
                                                                                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/renovatie-volledige-leidingsectie-met-buis-in-buissysteem-met-GVP-elementen'),
        'renovatie-volledige-leidingsectie-met-buis-in-buissysteem-met-GVP-panelen': KeuzelijstWaarde(invulwaarde='renovatie-volledige-leidingsectie-met-buis-in-buissysteem-met-GVP-panelen',
                                                                                                      label='renovatie volledige leidingsectie met buis in buissysteem met GVP-panelen',
                                                                                                      status='ingebruik',
                                                                                                      definitie='Renovatie volledige leidingsectie met buis in buissysteem met GVP-panelen',
                                                                                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/renovatie-volledige-leidingsectie-met-buis-in-buissysteem-met-GVP-panelen'),
        'rioolrenovatie-d.m.v.-deelrenovatie-met-glasvezelversterkt-kunsthars': KeuzelijstWaarde(invulwaarde='rioolrenovatie-d.m.v.-deelrenovatie-met-glasvezelversterkt-kunsthars',
                                                                                                 label='rioolrenovatie d.m.v. deelrenovatie met glasvezelversterkt kunsthars',
                                                                                                 status='ingebruik',
                                                                                                 definitie='Rioolrenovatie d.m.v. deelrenovatie met glasvezelversterkt kunsthars',
                                                                                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/rioolrenovatie-d.m.v.-deelrenovatie-met-glasvezelversterkt-kunsthars'),
        'rioolrenovatie-dmv-close-fit-lining-met-fabrieksmatig-gevouwen-HDPE-buizen-met-diameter': KeuzelijstWaarde(invulwaarde='rioolrenovatie-dmv-close-fit-lining-met-fabrieksmatig-gevouwen-HDPE-buizen-met-diameter',
                                                                                                                    label='rioolrenovatie dmv close-fit lining met fabrieksmatig gevouwen HDPE-buizen met diameter',
                                                                                                                    status='ingebruik',
                                                                                                                    definitie='Rioolrenovatie dmv close-fit lining met fabrieksmatig gevouwen HDPE-buizen met diameter',
                                                                                                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/rioolrenovatie-dmv-close-fit-lining-met-fabrieksmatig-gevouwen-HDPE-buizen-met-diameter'),
        'rioolrenovatie-door-middel-van-HDPE-grout-liner': KeuzelijstWaarde(invulwaarde='rioolrenovatie-door-middel-van-HDPE-grout-liner',
                                                                            label='rioolrenovatie door middel van HDPE-grout liner',
                                                                            status='ingebruik',
                                                                            definitie='Rioolrenovatie door middel van HDPE/grout liner',
                                                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/rioolrenovatie-door-middel-van-HDPE-grout-liner'),
        'uitwendige-aangepaste-PUR-bekleding-aangebracht-in-de-fabriek-voor-buizen-van-nodulair-gietijzer': KeuzelijstWaarde(invulwaarde='uitwendige-aangepaste-PUR-bekleding-aangebracht-in-de-fabriek-voor-buizen-van-nodulair-gietijzer',
                                                                                                                             label='uitwendige aangepaste PUR-bekleding aangebracht in de fabriek voor buizen van nodulair gietijzer',
                                                                                                                             status='ingebruik',
                                                                                                                             definitie='uitwendige aangepaste PUR-bekleding aangebracht in de fabriek voor buizen van nodulair gietijzer',
                                                                                                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/uitwendige-aangepaste-PUR-bekleding-aangebracht-in-de-fabriek-voor-buizen-van-nodulair-gietijzer'),
        'uitwendige-beschermbanden-met-PE-inlage-aangebracht-in-de-fabriek-voor-buizen-van-nodulair-gietijzer': KeuzelijstWaarde(invulwaarde='uitwendige-beschermbanden-met-PE-inlage-aangebracht-in-de-fabriek-voor-buizen-van-nodulair-gietijzer',
                                                                                                                                 label='uitwendige beschermbanden met PE-inlage aangebracht in de fabriek voor buizen van nodulair gietijzer',
                                                                                                                                 status='ingebruik',
                                                                                                                                 definitie='uitwendige beschermbanden met PE-inlage aangebracht in de fabriek voor buizen van nodulair gietijzer',
                                                                                                                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/uitwendige-beschermbanden-met-PE-inlage-aangebracht-in-de-fabriek-voor-buizen-van-nodulair-gietijzer'),
        'uitwendige-geextrudeerde-PE-bekleding-aangebracht-in-de-fabriek-voor-buizen-van-nodulair-gietijzer': KeuzelijstWaarde(invulwaarde='uitwendige-geextrudeerde-PE-bekleding-aangebracht-in-de-fabriek-voor-buizen-van-nodulair-gietijzer',
                                                                                                                               label='uitwendige geextrudeerde PE-bekleding aangebracht in de fabriek voor buizen van nodulair gietijzer',
                                                                                                                               status='ingebruik',
                                                                                                                               definitie='uitwendige geextrudeerde PE-bekleding aangebracht in de fabriek voor buizen van nodulair gietijzer',
                                                                                                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/uitwendige-geextrudeerde-PE-bekleding-aangebracht-in-de-fabriek-voor-buizen-van-nodulair-gietijzer'),
        'uitwendige-waterdichte-PE-folie-op-de-werf-aangebracht-voor-buizen-van-nodulair-gietijzer': KeuzelijstWaarde(invulwaarde='uitwendige-waterdichte-PE-folie-op-de-werf-aangebracht-voor-buizen-van-nodulair-gietijzer',
                                                                                                                      label='uitwendige waterdichte PE-folie op de werf aangebracht voor buizen van nodulair gietijzer',
                                                                                                                      status='ingebruik',
                                                                                                                      definitie='uitwendige waterdichte PE-folie op de werf aangebracht voor buizen van nodulair gietijzer',
                                                                                                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/uitwendige-waterdichte-PE-folie-op-de-werf-aangebracht-voor-buizen-van-nodulair-gietijzer'),
        'waterdichting-door-middel-van-injectieharsen': KeuzelijstWaarde(invulwaarde='waterdichting-door-middel-van-injectieharsen',
                                                                         label='waterdichting door middel van injectieharsen',
                                                                         status='ingebruik',
                                                                         definitie='Waterdichting door middel van injectieharsen',
                                                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/waterdichting-door-middel-van-injectieharsen'),
        'waterdichting-door-middel-van-injectieharsen-in-man-toegankelijke-riolen': KeuzelijstWaarde(invulwaarde='waterdichting-door-middel-van-injectieharsen-in-man-toegankelijke-riolen',
                                                                                                     label='waterdichting door middel van injectieharsen in man-toegankelijke riolen',
                                                                                                     status='ingebruik',
                                                                                                     definitie='Waterdichting door middel van injectieharsen in man-toegankelijke riolen',
                                                                                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/waterdichting-door-middel-van-injectieharsen-in-man-toegankelijke-riolen'),
        'waterdichting-van-lekkende-voegverbindingen-van-ronde-buizen-dmv-manchette': KeuzelijstWaarde(invulwaarde='waterdichting-van-lekkende-voegverbindingen-van-ronde-buizen-dmv-manchette',
                                                                                                       label='waterdichting van lekkende voegverbindingen van ronde buizen dmv manchette',
                                                                                                       status='ingebruik',
                                                                                                       definitie='Waterdichting van lekkende voegverbindingen van ronde buizen dmv manchette',
                                                                                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/waterdichting-van-lekkende-voegverbindingen-van-ronde-buizen-dmv-manchette'),
        'waterdichting-van-lekkende-voegverbindingen-van-ronde-buizen-dmv-uitwendige-krimpmof': KeuzelijstWaarde(invulwaarde='waterdichting-van-lekkende-voegverbindingen-van-ronde-buizen-dmv-uitwendige-krimpmof',
                                                                                                                 label='waterdichting van lekkende voegverbindingen van ronde buizen dmv uitwendige krimpmof',
                                                                                                                 status='ingebruik',
                                                                                                                 definitie='Waterdichting van lekkende voegverbindingen van ronde buizen dmv uitwendige krimpmof',
                                                                                                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBuisbekledingUitvoeringswijze/waterdichting-van-lekkende-voegverbindingen-van-ronde-buizen-dmv-uitwendige-krimpmof')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlLEGCOpstelling(KeuzelijstField):
    """De opstellingen van de geluidswerende constructie."""
    naam = 'KlLEGCOpstelling'
    label = 'Opstelling'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlLEGCOpstelling'
    definition = 'De opstellingen van de geluidswerende constructie.'
    status = 'ingebruik'
    deprecated_version = '2.0.0'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlLEGCOpstelling'
    options = {
        'concaaf': KeuzelijstWaarde(invulwaarde='concaaf',
                                    label='concaaf',
                                    status='ingebruik',
                                    definitie='Concave opstelling t.o.v. de weg',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEGCOpstelling/concaaf'),
        'schuin-naar-achter-hellend': KeuzelijstWaarde(invulwaarde='schuin-naar-achter-hellend',
                                                       label='schuin naar achter hellend',
                                                       status='ingebruik',
                                                       definitie='schuin naar achter hellend t.o.v. de weg',
                                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEGCOpstelling/schuin-naar-achter-hellend'),
        'schuin-naar-voor-hellend': KeuzelijstWaarde(invulwaarde='schuin-naar-voor-hellend',
                                                     label='schuin naar voor hellend',
                                                     status='ingebruik',
                                                     definitie='schuin naar voor hellend t.o.v. de weg',
                                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEGCOpstelling/schuin-naar-voor-hellend'),
        'verticaal': KeuzelijstWaarde(invulwaarde='verticaal',
                                      label='verticaal',
                                      status='ingebruik',
                                      definitie='verticaal t.o.v. de weg',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEGCOpstelling/verticaal')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlDunneOverlagingType(KeuzelijstField):
    """Types van dunne overlaging."""
    naam = 'KlDunneOverlagingType'
    label = 'Dunne overlaging type'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlDunneOverlagingType'
    definition = 'Types van dunne overlaging.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlDunneOverlagingType'
    options = {
        'SME-D1': KeuzelijstWaarde(invulwaarde='SME-D1',
                                   label='SME-D1',
                                   status='ingebruik',
                                   definitie='SME-D1',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDunneOverlagingType/SME-D1'),
        'SME-D2': KeuzelijstWaarde(invulwaarde='SME-D2',
                                   label='SME-D2',
                                   status='ingebruik',
                                   definitie='SMA-D2',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDunneOverlagingType/SME-D2'),
        'antisliplaag': KeuzelijstWaarde(invulwaarde='antisliplaag',
                                         label='antisliplaag',
                                         status='ingebruik',
                                         definitie='antisliplaag',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDunneOverlagingType/antisliplaag')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.ImplementatieElement.AIMObject import AIMObject
from otlmow_model.Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from otlmow_model.Datatypes.KlBekledingPlaats import KlBekledingPlaats
from otlmow_model.Datatypes.KlBuisbekledingUitvoeringswijze import KlBuisbekledingUitvoeringswijze
from otlmow_model.Datatypes.KwantWrdInMeter import KwantWrdInMeter, KwantWrdInMeterWaarden
from otlmow_model.Datatypes.KwantWrdInMillimeter import KwantWrdInMillimeter, KwantWrdInMillimeterWaarden
from otlmow_model.GeometrieTypes.LijnGeometrie import LijnGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Buisbekleding(AIMObject, LijnGeometrie):
    """De bekleding of coating ter bescherming van de buis."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Buisbekleding'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        AIMObject.__init__(self)
        LijnGeometrie.__init__(self)

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Buis')

        self._laagdikte = OTLAttribuut(field=KwantWrdInMillimeter,
                                       naam='laagdikte',
                                       label='Laagdikte',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Buisbekleding.laagdikte',
                                       definition='De dikte van de bekledingslaag in millimeter.',
                                       owner=self)

        self._lengte = OTLAttribuut(field=KwantWrdInMeter,
                                    naam='lengte',
                                    label='Lengte',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Buisbekleding.lengte',
                                    definition='De totale lengte van de buisbekleding in lopende meter.',
                                    owner=self)

        self._plaats = OTLAttribuut(field=KlBekledingPlaats,
                                    naam='plaats',
                                    label='plaats',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Buisbekleding.plaats',
                                    definition='De kant waar de bekleding van de buis zich bevindt.',
                                    owner=self)

        self._technischeFiche = OTLAttribuut(field=DtcDocument,
                                             naam='technischeFiche',
                                             label='technische fiche',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Buisbekleding.technischeFiche',
                                             definition='De technische fiche van de buisbekleding.',
                                             owner=self)

        self._tot = OTLAttribuut(field=KwantWrdInMeter,
                                 naam='tot',
                                 label='tot',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Buisbekleding.tot',
                                 definition='Het einde van de buisbekleding in meter ten opzichte van de beginput van de buis.',
                                 owner=self)

        self._uitvoeringswijze = OTLAttribuut(field=KlBuisbekledingUitvoeringswijze,
                                              naam='uitvoeringswijze',
                                              label='uitvoeringswijze',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Buisbekleding.uitvoeringswijze',
                                              definition='Materiaal en manier van aanbrengen van de buisbekleding.',
                                              owner=self)

        self._van = OTLAttribuut(field=KwantWrdInMeter,
                                 naam='van',
                                 label='van',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Buisbekleding.van',
                                 definition='Het begin van de buisbekleding in meter ten opzichte van de beginput van de leiding.',
                                 owner=self)

    @property
    def laagdikte(self) -> KwantWrdInMillimeterWaarden:
        """De dikte van de bekledingslaag in millimeter."""
        return self._laagdikte.get_waarde()

    @laagdikte.setter
    def laagdikte(self, value):
        self._laagdikte.set_waarde(value, owner=self)

    @property
    def lengte(self) -> KwantWrdInMeterWaarden:
        """De totale lengte van de buisbekleding in lopende meter."""
        return self._lengte.get_waarde()

    @lengte.setter
    def lengte(self, value):
        self._lengte.set_waarde(value, owner=self)

    @property
    def plaats(self) -> str:
        """De kant waar de bekleding van de buis zich bevindt."""
        return self._plaats.get_waarde()

    @plaats.setter
    def plaats(self, value):
        self._plaats.set_waarde(value, owner=self)

    @property
    def technischeFiche(self) -> DtcDocumentWaarden:
        """De technische fiche van de buisbekleding."""
        return self._technischeFiche.get_waarde()

    @technischeFiche.setter
    def technischeFiche(self, value):
        self._technischeFiche.set_waarde(value, owner=self)

    @property
    def tot(self) -> KwantWrdInMeterWaarden:
        """Het einde van de buisbekleding in meter ten opzichte van de beginput van de buis."""
        return self._tot.get_waarde()

    @tot.setter
    def tot(self, value):
        self._tot.set_waarde(value, owner=self)

    @property
    def uitvoeringswijze(self) -> str:
        """Materiaal en manier van aanbrengen van de buisbekleding."""
        return self._uitvoeringswijze.get_waarde()

    @uitvoeringswijze.setter
    def uitvoeringswijze(self, value):
        self._uitvoeringswijze.set_waarde(value, owner=self)

    @property
    def van(self) -> KwantWrdInMeterWaarden:
        """Het begin van de buisbekleding in meter ten opzichte van de beginput van de leiding."""
        return self._van.get_waarde()

    @van.setter
    def van(self, value):
        self._van.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from otlmow_model.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class MIVLuskaart(AIMNaamObject, PuntGeometrie):
    """Meten in Vlaanderen : kaart in LVE- of SAT- rack met de analoge circuits voor de lussen en analoog/digitaal conversie."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#MIVLuskaart'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        AIMNaamObject.__init__(self)
        PuntGeometrie.__init__(self)

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Rack')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#MIVInstallatie')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#SoftwareToegang')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LoopTerminationAndProtection')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#MIVCommunicatiekaart')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Netwerkpoort')

        self._lussenMeetrapport = OTLAttribuut(field=DtcDocument,
                                               naam='lussenMeetrapport',
                                               label='lussen meetrapport',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#MIVLuskaart.lussenMeetrapport',
                                               usagenote='Bestanden van het type pdf.',
                                               definition='De elektrische eigenschappen van de lus: R, L, C en de isolatieweerstand. Dit verzekert naast de afmetingen mee de voorziene nauwkeurigheid van de voertuigmetingen.',
                                               owner=self)

    @property
    def lussenMeetrapport(self) -> DtcDocumentWaarden:
        """De elektrische eigenschappen van de lus: R, L, C en de isolatieweerstand. Dit verzekert naast de afmetingen mee de voorziene nauwkeurigheid van de voertuigmetingen."""
        return self._lussenMeetrapport.get_waarde()

    @lussenMeetrapport.setter
    def lussenMeetrapport(self, value):
        self._lussenMeetrapport.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.ImplementatieElement.AIMObject import AIMObject
from otlmow_model.Datatypes.KlGrondherkomst import KlGrondherkomst
from otlmow_model.Datatypes.KwantWrdInVierkanteMeter import KwantWrdInVierkanteMeter, KwantWrdInVierkanteMeterWaarden


# Generated with OTLClassCreator. To modify: extend, do not edit
class Afdekking(AIMObject):
    """Wordt beschouwd als de verzameling van beheeractiviteiten die uitgevoerd kunnen worden op grond."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/levenscyclus#Afdekking'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self._herkomst = OTLAttribuut(field=KlGrondherkomst,
                                      naam='herkomst',
                                      label='herkomst',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/levenscyclus#Afdekking.herkomst',
                                      definition='De herkomst van de grond.',
                                      owner=self)

        self._oppervlakte = OTLAttribuut(field=KwantWrdInVierkanteMeter,
                                         naam='oppervlakte',
                                         label='oppervlakte',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/levenscyclus#Afdekking.oppervlakte',
                                         definition='De oppervlakte in vierkante meter van de afdekking.',
                                         owner=self)

    @property
    def herkomst(self) -> str:
        """De herkomst van de grond."""
        return self._herkomst.get_waarde()

    @herkomst.setter
    def herkomst(self, value):
        self._herkomst.set_waarde(value, owner=self)

    @property
    def oppervlakte(self) -> KwantWrdInVierkanteMeterWaarden:
        """De oppervlakte in vierkante meter van de afdekking."""
        return self._oppervlakte.get_waarde()

    @oppervlakte.setter
    def oppervlakte(self, value):
        self._oppervlakte.set_waarde(value, owner=self)



# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlCalamiteitsbordType(KeuzelijstField):
    """Types van calamiteitsbord."""
    naam = 'KlCalamiteitsbordType'
    label = 'Calamiteitsbord type'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlCalamiteitsbordType'
    definition = 'Types van calamiteitsbord.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlCalamiteitsbordType'
    options = {
        'draaiend-bord': KeuzelijstWaarde(invulwaarde='draaiend-bord',
                                          label='draaiend bord',
                                          status='ingebruik',
                                          definitie='Een draaiend calamiteitsbord.',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlCalamiteitsbordType/draaiend-bord'),
        'dragend-bord': KeuzelijstWaarde(invulwaarde='dragend-bord',
                                         label='dragend bord',
                                         status='ingebruik',
                                         definitie='Een dragend calamiteitsbord.',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlCalamiteitsbordType/dragend-bord')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut
from otlmow_model.Classes.Abstracten.Kabel import Kabel
from otlmow_model.Datatypes.KlElectricitySubthema import KlElectricitySubthema
from otlmow_model.Datatypes.KwantWrdInVolt import KwantWrdInVolt, KwantWrdInVoltWaarden


# Generated with OTLClassCreator. To modify: extend, do not edit
class ElectricityCable(Kabel):
    """Een aansluiting of reeks aansluitingen van een nutsvoorzieningennet voor het overbrengen van elektriciteit van de ene locatie naar een andere."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#ElectricityCable'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self._nominaleSpanning = OTLAttribuut(field=KwantWrdInVolt,
                                              naam='nominaleSpanning',
                                              label='nominale spanning',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#ElectricityCable.nominaleSpanning',
                                              definition='Beschrijft de nominale systeemspanning op de plaats van levering.',
                                              owner=self)

        self._operationeleSpanning = OTLAttribuut(field=KwantWrdInVolt,
                                                  naam='operationeleSpanning',
                                                  label='operationele spanning',
                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#ElectricityCable.operationeleSpanning',
                                                  definition='Beschrijft de gebruiks- of bedrijfsspanning op de leiding.',
                                                  owner=self)

        self._subthema = OTLAttribuut(field=KlElectricitySubthema,
                                      naam='subthema',
                                      label='subthema',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#ElectricityCable.subthema',
                                      definition='Classificatie van een kabel, leiding, of leidingelementen volgens het thematisch domein waar deze toe behoren.',
                                      owner=self)

    @property
    def nominaleSpanning(self) -> KwantWrdInVoltWaarden:
        """Beschrijft de nominale systeemspanning op de plaats van levering."""
        return self._nominaleSpanning.get_waarde()

    @nominaleSpanning.setter
    def nominaleSpanning(self, value):
        self._nominaleSpanning.set_waarde(value, owner=self)

    @property
    def operationeleSpanning(self) -> KwantWrdInVoltWaarden:
        """Beschrijft de gebruiks- of bedrijfsspanning op de leiding."""
        return self._operationeleSpanning.get_waarde()

    @operationeleSpanning.setter
    def operationeleSpanning(self, value):
        self._operationeleSpanning.set_waarde(value, owner=self)

    @property
    def subthema(self) -> str:
        """Classificatie van een kabel, leiding, of leidingelementen volgens het thematisch domein waar deze toe behoren."""
        return self._subthema.get_waarde()

    @subthema.setter
    def subthema(self, value):
        self._subthema.set_waarde(value, owner=self)



# coding=utf-8
from abc import abstractmethod
from otlmow_model.Classes.Abstracten.Communicatieapparatuur import Communicatieapparatuur
from otlmow_model.Classes.Abstracten.FirmwareObject import FirmwareObject


# Generated with OTLClassCreator. To modify: extend, do not edit
class ZenderOntvangerToegang(Communicatieapparatuur, FirmwareObject):
    """Abstracte voor relaties van Zender,Ontvanger en Repeater met andere apparatuur."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ZenderOntvangerToegang'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    @abstractmethod
    def __init__(self):
        Communicatieapparatuur.__init__(self)
        FirmwareObject.__init__(self)

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestigingsbeugel')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#WeggebondenDetector')



# coding=utf-8
import random
from otlmow_model.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlMeetcelVeiligheidsfactor(KeuzelijstField):
    """Verhouding tussen de toegekende primaire limietstroom van de meetcel en de toegekende primaire stroom."""
    naam = 'KlMeetcelVeiligheidsfactor'
    label = 'Meetcel veiligheidsfactor'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlMeetcelVeiligheidsfactor'
    definition = 'Verhouding tussen de toegekende primaire limietstroom van de meetcel en de toegekende primaire stroom.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlMeetcelVeiligheidsfactor'
    options = {
        'fS-5': KeuzelijstWaarde(invulwaarde='fS-5',
                                 label='fS 5',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlMeetcelVeiligheidsfactor/fS-5')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)

